/****************************************************************************
** Meta object code from reading C++ file 'SpectacleCore.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/SpectacleCore.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SpectacleCore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13SpectacleCoreE_t {};
} // unnamed namespace

template <> constexpr inline auto SpectacleCore::qt_create_metaobjectdata<qt_meta_tag_ZN13SpectacleCoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpectacleCore",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "screenCaptureUrlChanged",
        "",
        "captureTimeRemainingChanged",
        "captureProgressChanged",
        "allDone",
        "dbusScreenshotFailed",
        "message",
        "dbusRecordingFailed",
        "videoModeChanged",
        "videoMode",
        "currentVideoChanged",
        "QUrl",
        "currentVideo",
        "recordedTimeChanged",
        "ocrStatusChanged",
        "activate",
        "arguments",
        "workingDirectory",
        "takeNewScreenshot",
        "captureMode",
        "timeout",
        "includePointer",
        "includeDecorations",
        "includeShadow",
        "cancelScreenshot",
        "showErrorMessage",
        "ocrAvailableLanguages",
        "QVariantMap",
        "startOcrExtraction",
        "languageCode",
        "startRecording",
        "VideoPlatform::RecordingMode",
        "mode",
        "withPointer",
        "finishRecording",
        "timeFromMilliseconds",
        "milliseconds",
        "imagePlatform",
        "ImagePlatform*",
        "videoPlatform",
        "VideoPlatform*",
        "screenCaptureUrl",
        "captureTimeRemaining",
        "captureProgress",
        "recordedTime",
        "annotationDocument",
        "AnnotationDocument*",
        "ocrAvailable",
        "ocrStatus",
        "OcrManager::OcrStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'screenCaptureUrlChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureTimeRemainingChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureProgressChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allDone'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dbusScreenshotFailed'
        QtMocHelpers::SignalData<void(const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'dbusRecordingFailed'
        QtMocHelpers::SignalData<void(const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'videoModeChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'currentVideoChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'recordedTimeChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ocrStatusChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activate'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'takeNewScreenshot'
        QtMocHelpers::SlotData<void(int, int, bool, bool, bool)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { QMetaType::Bool, 26 }, { QMetaType::Bool, 27 },
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'takeNewScreenshot'
        QtMocHelpers::SlotData<void(int, int, bool, bool)>(23, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { QMetaType::Bool, 26 }, { QMetaType::Bool, 27 },
        }}),
        // Slot 'takeNewScreenshot'
        QtMocHelpers::SlotData<void(int, int, bool)>(23, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'takeNewScreenshot'
        QtMocHelpers::SlotData<void(int, int)>(23, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'takeNewScreenshot'
        QtMocHelpers::SlotData<void(int)>(23, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'takeNewScreenshot'
        QtMocHelpers::SlotData<void()>(23, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'cancelScreenshot'
        QtMocHelpers::SlotData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Method 'ocrAvailableLanguages'
        QtMocHelpers::MethodData<QVariantMap() const>(31, 6, QMC::AccessPublic, 0x80000000 | 32),
        // Method 'startOcrExtraction'
        QtMocHelpers::MethodData<bool(const QString &)>(33, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 34 },
        }}),
        // Method 'startOcrExtraction'
        QtMocHelpers::MethodData<bool()>(33, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'startRecording'
        QtMocHelpers::MethodData<void(VideoPlatform::RecordingMode, bool)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::Bool, 38 },
        }}),
        // Method 'startRecording'
        QtMocHelpers::MethodData<void(VideoPlatform::RecordingMode)>(35, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Method 'finishRecording'
        QtMocHelpers::MethodData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'timeFromMilliseconds'
        QtMocHelpers::MethodData<QString(qint64) const>(40, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::LongLong, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'imagePlatform'
        QtMocHelpers::PropertyData<ImagePlatform*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'videoPlatform'
        QtMocHelpers::PropertyData<VideoPlatform*>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'screenCaptureUrl'
        QtMocHelpers::PropertyData<QUrl>(46, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'captureTimeRemaining'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'captureProgress'
        QtMocHelpers::PropertyData<qreal>(48, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'recordedTime'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'videoMode'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'currentVideo'
        QtMocHelpers::PropertyData<QUrl>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'annotationDocument'
        QtMocHelpers::PropertyData<AnnotationDocument*>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'ocrAvailable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'ocrStatus'
        QtMocHelpers::PropertyData<OcrManager::OcrStatus>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SpectacleCore, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN13SpectacleCoreE[] = {
    QMetaObject::SuperData::link<OcrManager::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject SpectacleCore::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SpectacleCoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SpectacleCoreE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN13SpectacleCoreE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SpectacleCoreE_t>.metaTypes,
    nullptr
} };

void SpectacleCore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpectacleCore *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->screenCaptureUrlChanged(); break;
        case 1: _t->captureTimeRemainingChanged(); break;
        case 2: _t->captureProgressChanged(); break;
        case 3: _t->allDone(); break;
        case 4: _t->dbusScreenshotFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->dbusRecordingFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->videoModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->currentVideoChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->recordedTimeChanged(); break;
        case 9: _t->ocrStatusChanged(); break;
        case 10: _t->activate((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->takeNewScreenshot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 12: _t->takeNewScreenshot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 13: _t->takeNewScreenshot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->takeNewScreenshot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->takeNewScreenshot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->takeNewScreenshot(); break;
        case 17: _t->cancelScreenshot(); break;
        case 18: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: { QVariantMap _r = _t->ocrAvailableLanguages();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->startOcrExtraction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->startOcrExtraction();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->startRecording((*reinterpret_cast<std::add_pointer_t<VideoPlatform::RecordingMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 23: _t->startRecording((*reinterpret_cast<std::add_pointer_t<VideoPlatform::RecordingMode>>(_a[1]))); break;
        case 24: _t->finishRecording(); break;
        case 25: { QString _r = _t->timeFromMilliseconds((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)()>(_a, &SpectacleCore::screenCaptureUrlChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)()>(_a, &SpectacleCore::captureTimeRemainingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)()>(_a, &SpectacleCore::captureProgressChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)()>(_a, &SpectacleCore::allDone, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)(const QString & )>(_a, &SpectacleCore::dbusScreenshotFailed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)(const QString & )>(_a, &SpectacleCore::dbusRecordingFailed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)(bool )>(_a, &SpectacleCore::videoModeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)(const QUrl & )>(_a, &SpectacleCore::currentVideoChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)()>(_a, &SpectacleCore::recordedTimeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleCore::*)()>(_a, &SpectacleCore::ocrStatusChanged, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AnnotationDocument* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ImagePlatform* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< VideoPlatform* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ImagePlatform**>(_v) = _t->imagePlatform(); break;
        case 1: *reinterpret_cast<VideoPlatform**>(_v) = _t->videoPlatform(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->screenCaptureUrl(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->captureTimeRemaining(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->captureProgress(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->recordedTime(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->videoMode(); break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->currentVideo(); break;
        case 8: *reinterpret_cast<AnnotationDocument**>(_v) = _t->annotationDocument(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->ocrAvailable(); break;
        case 10: *reinterpret_cast<OcrManager::OcrStatus*>(_v) = _t->ocrStatus(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setVideoMode(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SpectacleCore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpectacleCore::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SpectacleCoreE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SpectacleCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void SpectacleCore::screenCaptureUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SpectacleCore::captureTimeRemainingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SpectacleCore::captureProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SpectacleCore::allDone()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SpectacleCore::dbusScreenshotFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SpectacleCore::dbusRecordingFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SpectacleCore::videoModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void SpectacleCore::currentVideoChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void SpectacleCore::recordedTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SpectacleCore::ocrStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
