/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<CaptureModeModel.h>)
#  include <CaptureModeModel.h>
#endif
#if __has_include(<ExportMenu.h>)
#  include <ExportMenu.h>
#endif
#if __has_include(<Geometry.h>)
#  include <Geometry.h>
#endif
#if __has_include(<HelpMenu.h>)
#  include <HelpMenu.h>
#endif
#if __has_include(<ImagePlatform.h>)
#  include <ImagePlatform.h>
#endif
#if __has_include(<InlineMessageModel.h>)
#  include <InlineMessageModel.h>
#endif
#if __has_include(<OptionsMenu.h>)
#  include <OptionsMenu.h>
#endif
#if __has_include(<RecordingModeMenu.h>)
#  include <RecordingModeMenu.h>
#endif
#if __has_include(<RecordingModeModel.h>)
#  include <RecordingModeModel.h>
#endif
#if __has_include(<ScreenshotModeMenu.h>)
#  include <ScreenshotModeMenu.h>
#endif
#if __has_include(<Selection.h>)
#  include <Selection.h>
#endif
#if __has_include(<SelectionEditor.h>)
#  include <SelectionEditor.h>
#endif
#if __has_include(<SpectacleCore.h>)
#  include <SpectacleCore.h>
#endif
#if __has_include(<TextContextMenu.h>)
#  include <TextContextMenu.h>
#endif
#if __has_include(<VideoFormatModel.h>)
#  include <VideoFormatModel.h>
#endif
#if __has_include(<VideoPlatform.h>)
#  include <VideoPlatform.h>
#endif
#if __has_include(<settings.h>)
#  include <settings.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_spectacle_private()
{
    qmlRegisterModule("org.kde.spectacle.private", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<CaptureModeModel>("org.kde.spectacle.private", 254);
    qmlRegisterAnonymousType<QAbstractItemModel, 254>("org.kde.spectacle.private", 254);
    qmlRegisterEnum<CaptureModeModel::CaptureMode>("CaptureModeModel::CaptureMode");
    qmlRegisterTypesAndRevisions<ExportMenu>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<Geometry>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<HelpMenu>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<ImagePlatform>("org.kde.spectacle.private", 254);
    qmlRegisterEnum<ImagePlatform::GrabModes>("ImagePlatform::GrabModes");
    qmlRegisterEnum<ImagePlatform::GrabMode>("ImagePlatform::GrabMode");
    qmlRegisterEnum<ImagePlatform::ShutterModes>("ImagePlatform::ShutterModes");
    qmlRegisterEnum<ImagePlatform::ShutterMode>("ImagePlatform::ShutterMode");
    qmlRegisterTypesAndRevisions<InlineMessageModel>("org.kde.spectacle.private", 254);
    qmlRegisterEnum<InlineMessageModel::CustomRoles>("InlineMessageModel::CustomRoles");
    qmlRegisterEnum<InlineMessageModel::InlineMessageType>("InlineMessageModel::InlineMessageType");
    qmlRegisterTypesAndRevisions<OptionsMenu>("org.kde.spectacle.private", 254);
    QMetaType::fromType<QMenu *>().id();
    QMetaType::fromType<QWidget *>().id();
    qmlRegisterTypesAndRevisions<RecordingModeMenu>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<RecordingModeModel>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<ScreenshotModeMenu>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<Selection>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<SelectionEditor>("org.kde.spectacle.private", 254);
    qmlRegisterEnum<SelectionEditor::Location>("SelectionEditor::Location");
    qmlRegisterTypesAndRevisions<Settings>("org.kde.spectacle.private", 254);
    qmlRegisterEnum<Settings::EnumLaunchAction>("Settings::EnumLaunchAction");
    qmlRegisterEnum<Settings::EnumPrintKeyRunningAction>("Settings::EnumPrintKeyRunningAction");
    qmlRegisterEnum<Settings::EnumClipboardGroup>("Settings::EnumClipboardGroup");
    qmlRegisterEnum<Settings::EnumShowMagnifier>("Settings::EnumShowMagnifier");
    qmlRegisterEnum<Settings::EnumRememberSelectionRect>("Settings::EnumRememberSelectionRect");
    qmlRegisterTypesAndRevisions<SpectacleCore>("org.kde.spectacle.private", 254);
    QMetaType::fromType<SpectacleMenu *>().id();
    qmlRegisterTypesAndRevisions<TextContextMenu>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<VideoFormatModel>("org.kde.spectacle.private", 254);
    qmlRegisterTypesAndRevisions<VideoPlatform>("org.kde.spectacle.private", 254);
    qmlRegisterEnum<VideoPlatform::RecordingMode>("VideoPlatform::RecordingMode");
    qmlRegisterEnum<VideoPlatform::RecordingState>("VideoPlatform::RecordingState");
    qmlRegisterEnum<VideoPlatform::Format>("VideoPlatform::Format");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.spectacle.private", 254, 254);
}

static const QQmlModuleRegistration orgkdespectacleprivateRegistration("org.kde.spectacle.private", qml_register_types_org_kde_spectacle_private);
