/****************************************************************************
** Meta object code from reading C++ file 'ImagePlatformKWin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Platforms/ImagePlatformKWin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ImagePlatformKWin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ImagePlatformKWinE_t {};
} // unnamed namespace

template <> constexpr inline auto ImagePlatformKWin::qt_create_metaobjectdata<qt_meta_tag_ZN17ImagePlatformKWinE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImagePlatformKWin",
        "doGrab",
        "",
        "ImagePlatform::ShutterMode",
        "shutterMode",
        "ImagePlatform::GrabMode",
        "grabMode",
        "includePointer",
        "includeDecorations",
        "includeShadow",
        "updateSupportedGrabModes"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doGrab'
        QtMocHelpers::SlotData<void(ImagePlatform::ShutterMode, ImagePlatform::GrabMode, bool, bool, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::Bool, 7 }, { QMetaType::Bool, 8 },
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'updateSupportedGrabModes'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImagePlatformKWin, qt_meta_tag_ZN17ImagePlatformKWinE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImagePlatformKWin::staticMetaObject = { {
    QMetaObject::SuperData::link<ImagePlatform::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ImagePlatformKWinE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ImagePlatformKWinE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ImagePlatformKWinE_t>.metaTypes,
    nullptr
} };

void ImagePlatformKWin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImagePlatformKWin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doGrab((*reinterpret_cast<std::add_pointer_t<ImagePlatform::ShutterMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ImagePlatform::GrabMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 1: _t->updateSupportedGrabModes(); break;
        default: ;
        }
    }
}

const QMetaObject *ImagePlatformKWin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImagePlatformKWin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ImagePlatformKWinE_t>.strings))
        return static_cast<void*>(this);
    return ImagePlatform::qt_metacast(_clname);
}

int ImagePlatformKWin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ImagePlatform::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN17ScreenShotSource2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSource2::qt_create_metaobjectdata<qt_meta_tag_ZN17ScreenShotSource2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSource2",
        "finished",
        "",
        "ResultVariant",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(const ResultVariant &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSource2, qt_meta_tag_ZN17ScreenShotSource2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSource2::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenShotSource2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenShotSource2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ScreenShotSource2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSource2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSource2 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<ResultVariant>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenShotSource2::*)(const ResultVariant & )>(_a, &ScreenShotSource2::finished, 0))
            return;
    }
}

const QMetaObject *ScreenShotSource2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSource2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenShotSource2E_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenShotSource2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ScreenShotSource2::finished(const ResultVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN21ScreenShotSourceArea2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSourceArea2::qt_create_metaobjectdata<qt_meta_tag_ZN21ScreenShotSourceArea2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSourceArea2"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSourceArea2, qt_meta_tag_ZN21ScreenShotSourceArea2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSourceArea2::staticMetaObject = { {
    QMetaObject::SuperData::link<ScreenShotSource2::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ScreenShotSourceArea2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ScreenShotSourceArea2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ScreenShotSourceArea2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSourceArea2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSourceArea2 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenShotSourceArea2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSourceArea2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ScreenShotSourceArea2E_t>.strings))
        return static_cast<void*>(this);
    return ScreenShotSource2::qt_metacast(_clname);
}

int ScreenShotSourceArea2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScreenShotSource2::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN28ScreenShotSourceInteractive2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSourceInteractive2::qt_create_metaobjectdata<qt_meta_tag_ZN28ScreenShotSourceInteractive2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSourceInteractive2"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSourceInteractive2, qt_meta_tag_ZN28ScreenShotSourceInteractive2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSourceInteractive2::staticMetaObject = { {
    QMetaObject::SuperData::link<ScreenShotSource2::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28ScreenShotSourceInteractive2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28ScreenShotSourceInteractive2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28ScreenShotSourceInteractive2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSourceInteractive2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSourceInteractive2 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenShotSourceInteractive2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSourceInteractive2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28ScreenShotSourceInteractive2E_t>.strings))
        return static_cast<void*>(this);
    return ScreenShotSource2::qt_metacast(_clname);
}

int ScreenShotSourceInteractive2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScreenShotSource2::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23ScreenShotSourceScreen2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSourceScreen2::qt_create_metaobjectdata<qt_meta_tag_ZN23ScreenShotSourceScreen2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSourceScreen2"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSourceScreen2, qt_meta_tag_ZN23ScreenShotSourceScreen2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSourceScreen2::staticMetaObject = { {
    QMetaObject::SuperData::link<ScreenShotSource2::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScreenShotSourceScreen2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScreenShotSourceScreen2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ScreenShotSourceScreen2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSourceScreen2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSourceScreen2 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenShotSourceScreen2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSourceScreen2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScreenShotSourceScreen2E_t>.strings))
        return static_cast<void*>(this);
    return ScreenShotSource2::qt_metacast(_clname);
}

int ScreenShotSourceScreen2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScreenShotSource2::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN29ScreenShotSourceActiveWindow2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSourceActiveWindow2::qt_create_metaobjectdata<qt_meta_tag_ZN29ScreenShotSourceActiveWindow2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSourceActiveWindow2"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSourceActiveWindow2, qt_meta_tag_ZN29ScreenShotSourceActiveWindow2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSourceActiveWindow2::staticMetaObject = { {
    QMetaObject::SuperData::link<ScreenShotSource2::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ScreenShotSourceActiveWindow2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ScreenShotSourceActiveWindow2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29ScreenShotSourceActiveWindow2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSourceActiveWindow2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSourceActiveWindow2 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenShotSourceActiveWindow2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSourceActiveWindow2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ScreenShotSourceActiveWindow2E_t>.strings))
        return static_cast<void*>(this);
    return ScreenShotSource2::qt_metacast(_clname);
}

int ScreenShotSourceActiveWindow2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScreenShotSource2::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN29ScreenShotSourceActiveScreen2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSourceActiveScreen2::qt_create_metaobjectdata<qt_meta_tag_ZN29ScreenShotSourceActiveScreen2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSourceActiveScreen2"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSourceActiveScreen2, qt_meta_tag_ZN29ScreenShotSourceActiveScreen2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSourceActiveScreen2::staticMetaObject = { {
    QMetaObject::SuperData::link<ScreenShotSource2::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ScreenShotSourceActiveScreen2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ScreenShotSourceActiveScreen2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29ScreenShotSourceActiveScreen2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSourceActiveScreen2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSourceActiveScreen2 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenShotSourceActiveScreen2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSourceActiveScreen2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ScreenShotSourceActiveScreen2E_t>.strings))
        return static_cast<void*>(this);
    return ScreenShotSource2::qt_metacast(_clname);
}

int ScreenShotSourceActiveScreen2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScreenShotSource2::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN21ScreenShotSourceMeta2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSourceMeta2::qt_create_metaobjectdata<qt_meta_tag_ZN21ScreenShotSourceMeta2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSourceMeta2",
        "finished",
        "",
        "QList<ResultVariant>",
        "results"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(const QList<ResultVariant> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSourceMeta2, qt_meta_tag_ZN21ScreenShotSourceMeta2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSourceMeta2::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ScreenShotSourceMeta2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ScreenShotSourceMeta2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ScreenShotSourceMeta2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSourceMeta2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSourceMeta2 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<QList<ResultVariant>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenShotSourceMeta2::*)(const QList<ResultVariant> & )>(_a, &ScreenShotSourceMeta2::finished, 0))
            return;
    }
}

const QMetaObject *ScreenShotSourceMeta2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSourceMeta2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ScreenShotSourceMeta2E_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenShotSourceMeta2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ScreenShotSourceMeta2::finished(const QList<ResultVariant> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN26ScreenShotSourceWorkspace2E_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenShotSourceWorkspace2::qt_create_metaobjectdata<qt_meta_tag_ZN26ScreenShotSourceWorkspace2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenShotSourceWorkspace2"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenShotSourceWorkspace2, qt_meta_tag_ZN26ScreenShotSourceWorkspace2E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenShotSourceWorkspace2::staticMetaObject = { {
    QMetaObject::SuperData::link<ScreenShotSource2::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ScreenShotSourceWorkspace2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ScreenShotSourceWorkspace2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26ScreenShotSourceWorkspace2E_t>.metaTypes,
    nullptr
} };

void ScreenShotSourceWorkspace2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenShotSourceWorkspace2 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenShotSourceWorkspace2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenShotSourceWorkspace2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ScreenShotSourceWorkspace2E_t>.strings))
        return static_cast<void*>(this);
    return ScreenShotSource2::qt_metacast(_clname);
}

int ScreenShotSourceWorkspace2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScreenShotSource2::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
