/****************************************************************************
** Meta object code from reading C++ file 'SelectionEditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Gui/SelectionEditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SelectionEditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SelectionEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto SelectionEditor::qt_create_metaobjectdata<qt_meta_tag_ZN15SelectionEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SelectionEditor",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "devicePixelRatioChanged",
        "",
        "screensRectChanged",
        "dragLocationChanged",
        "handlesRectChanged",
        "mousePositionChanged",
        "showMagnifierChanged",
        "magnifierLocationChanged",
        "accepted",
        "QRectF",
        "rect",
        "ExportManager::Actions",
        "actions",
        "acceptSelection",
        "selection",
        "Selection*",
        "devicePixelRatio",
        "screensRect",
        "dragLocation",
        "Location",
        "handlesRect",
        "mousePosition",
        "QPointF",
        "showMagnifier",
        "magnifierLocation",
        "None",
        "Outside",
        "TopLeft",
        "Top",
        "TopRight",
        "Left",
        "Inside",
        "Right",
        "BottomLeft",
        "Bottom",
        "BottomRight",
        "FollowMouse"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'devicePixelRatioChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screensRectChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragLocationChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'handlesRectChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mousePositionChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showMagnifierChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'magnifierLocationChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accepted'
        QtMocHelpers::SignalData<void(const QRectF &, const ExportManager::Actions &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'acceptSelection'
        QtMocHelpers::SlotData<bool(ExportManager::Actions)>(18, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'acceptSelection'
        QtMocHelpers::SlotData<bool()>(18, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'selection'
        QtMocHelpers::PropertyData<Selection*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'devicePixelRatio'
        QtMocHelpers::PropertyData<qreal>(21, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'screensRect'
        QtMocHelpers::PropertyData<QRectF>(22, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'dragLocation'
        QtMocHelpers::PropertyData<enum Location>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'handlesRect'
        QtMocHelpers::PropertyData<QRectF>(25, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 3),
        // property 'mousePosition'
        QtMocHelpers::PropertyData<QPointF>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'showMagnifier'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'magnifierLocation'
        QtMocHelpers::PropertyData<enum Location>(29, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Location'
        QtMocHelpers::EnumData<enum Location>(24, 24, QMC::EnumFlags{}).add({
            {   30, Location::None },
            {   31, Location::Outside },
            {   32, Location::TopLeft },
            {   33, Location::Top },
            {   34, Location::TopRight },
            {   35, Location::Left },
            {   36, Location::Inside },
            {   37, Location::Right },
            {   38, Location::BottomLeft },
            {   39, Location::Bottom },
            {   40, Location::BottomRight },
            {   41, Location::FollowMouse },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SelectionEditor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SelectionEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SelectionEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SelectionEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SelectionEditorE_t>.metaTypes,
    nullptr
} };

void SelectionEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SelectionEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->devicePixelRatioChanged(); break;
        case 1: _t->screensRectChanged(); break;
        case 2: _t->dragLocationChanged(); break;
        case 3: _t->handlesRectChanged(); break;
        case 4: _t->mousePositionChanged(); break;
        case 5: _t->showMagnifierChanged(); break;
        case 6: _t->magnifierLocationChanged(); break;
        case 7: _t->accepted((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ExportManager::Actions>>(_a[2]))); break;
        case 8: { bool _r = _t->acceptSelection((*reinterpret_cast<std::add_pointer_t<ExportManager::Actions>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->acceptSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::devicePixelRatioChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::screensRectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::dragLocationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::handlesRectChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::mousePositionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::showMagnifierChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::magnifierLocationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)(const QRectF & , const ExportManager::Actions & )>(_a, &SelectionEditor::accepted, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Selection* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Selection**>(_v) = _t->selection(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->devicePixelRatio(); break;
        case 2: *reinterpret_cast<QRectF*>(_v) = _t->screensRect(); break;
        case 3: *reinterpret_cast<enum Location*>(_v) = _t->dragLocation(); break;
        case 4: *reinterpret_cast<QRectF*>(_v) = _t->handlesRect(); break;
        case 5: *reinterpret_cast<QPointF*>(_v) = _t->mousePosition(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showMagnifier(); break;
        case 7: *reinterpret_cast<enum Location*>(_v) = _t->magnifierLocation(); break;
        default: break;
        }
    }
}

const QMetaObject *SelectionEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SelectionEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SelectionEditorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SelectionEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SelectionEditor::devicePixelRatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SelectionEditor::screensRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SelectionEditor::dragLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SelectionEditor::handlesRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SelectionEditor::mousePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SelectionEditor::showMagnifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SelectionEditor::magnifierLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SelectionEditor::accepted(const QRectF & _t1, const ExportManager::Actions & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
