/********************************************************************************
** Form generated from reading UI file 'VideoSaveOptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VIDEOSAVEOPTIONS_H
#define UI_VIDEOSAVEOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_VideoSaveOptions
{
public:
    QFormLayout *formLayout;
    QLabel *saveLocationLabel;
    KUrlRequester *kcfg_videoSaveLocation;
    QLabel *filenameLabel;
    QHBoxLayout *saveLayout;
    QLineEdit *kcfg_videoFilenameTemplate;
    QLabel *previewLabel;
    QLabel *preview;
    QLabel *captureInstructionLabel;

    void setupUi(QWidget *VideoSaveOptions)
    {
        if (VideoSaveOptions->objectName().isEmpty())
            VideoSaveOptions->setObjectName("VideoSaveOptions");
        formLayout = new QFormLayout(VideoSaveOptions);
        formLayout->setObjectName("formLayout");
        saveLocationLabel = new QLabel(VideoSaveOptions);
        saveLocationLabel->setObjectName("saveLocationLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, saveLocationLabel);

        kcfg_videoSaveLocation = new KUrlRequester(VideoSaveOptions);
        kcfg_videoSaveLocation->setObjectName("kcfg_videoSaveLocation");
        kcfg_videoSaveLocation->setMode(KFile::Directory|KFile::LocalOnly);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_videoSaveLocation);

        filenameLabel = new QLabel(VideoSaveOptions);
        filenameLabel->setObjectName("filenameLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, filenameLabel);

        saveLayout = new QHBoxLayout();
        saveLayout->setObjectName("saveLayout");
        kcfg_videoFilenameTemplate = new QLineEdit(VideoSaveOptions);
        kcfg_videoFilenameTemplate->setObjectName("kcfg_videoFilenameTemplate");
        kcfg_videoFilenameTemplate->setPlaceholderText(QString::fromUtf8("%d"));

        saveLayout->addWidget(kcfg_videoFilenameTemplate);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, saveLayout);

        previewLabel = new QLabel(VideoSaveOptions);
        previewLabel->setObjectName("previewLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, previewLabel);

        preview = new QLabel(VideoSaveOptions);
        preview->setObjectName("preview");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, preview);

        captureInstructionLabel = new QLabel(VideoSaveOptions);
        captureInstructionLabel->setObjectName("captureInstructionLabel");
        captureInstructionLabel->setTextFormat(Qt::RichText);
        captureInstructionLabel->setWordWrap(true);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, captureInstructionLabel);

#if QT_CONFIG(shortcut)
        saveLocationLabel->setBuddy(kcfg_videoSaveLocation);
        filenameLabel->setBuddy(kcfg_videoFilenameTemplate);
#endif // QT_CONFIG(shortcut)

        retranslateUi(VideoSaveOptions);

        QMetaObject::connectSlotsByName(VideoSaveOptions);
    } // setupUi

    void retranslateUi(QWidget *VideoSaveOptions)
    {
        saveLocationLabel->setText(tr2i18n("Save &Location:", nullptr));
        filenameLabel->setText(tr2i18n("Filename:", nullptr));
        previewLabel->setText(tr2i18n("Preview:", "Preview of the user configured filename"));
        preview->setText(QString());
        captureInstructionLabel->setText(QString());
        (void)VideoSaveOptions;
    } // retranslateUi

};

namespace Ui {
    class VideoSaveOptions: public Ui_VideoSaveOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VIDEOSAVEOPTIONS_H

