/****************************************************************************
** Meta object code from reading C++ file 'ImagePlatform.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Platforms/ImagePlatform.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ImagePlatform.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ImagePlatformE_t {};
} // unnamed namespace

template <> constexpr inline auto ImagePlatform::qt_create_metaobjectdata<qt_meta_tag_ZN13ImagePlatformE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImagePlatform",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Created by SpectacleCore",
        "supportedGrabModesChanged",
        "",
        "newScreenshotTaken",
        "QImage",
        "image",
        "newCroppableScreenshotTaken",
        "newScreenshotFailed",
        "message",
        "newScreenshotCanceled",
        "doGrab",
        "ImagePlatform::ShutterMode",
        "shutterMode",
        "ImagePlatform::GrabMode",
        "grabMode",
        "includePointer",
        "includeDecorations",
        "includeShadow",
        "supportedGrabModes",
        "GrabModes",
        "supportedShutterModes",
        "ShutterModes",
        "GrabMode",
        "NoGrabModes",
        "AllScreens",
        "CurrentScreen",
        "ActiveWindow",
        "WindowUnderCursor",
        "TransientWithParent",
        "AllScreensScaled",
        "PerScreenImageNative",
        "ShutterMode",
        "Immediate",
        "OnClick"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'supportedGrabModesChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newScreenshotTaken'
        QtMocHelpers::SignalData<void(const QImage &)>(9, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'newScreenshotTaken'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'newCroppableScreenshotTaken'
        QtMocHelpers::SignalData<void(const QImage &)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'newScreenshotFailed'
        QtMocHelpers::SignalData<void(const QString &)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'newScreenshotFailed'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'newScreenshotCanceled'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doGrab'
        QtMocHelpers::SlotData<void(ImagePlatform::ShutterMode, ImagePlatform::GrabMode, bool, bool, bool)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 }, { QMetaType::Bool, 21 }, { QMetaType::Bool, 22 },
            { QMetaType::Bool, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'supportedGrabModes'
        QtMocHelpers::PropertyData<GrabModes>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'supportedShutterModes'
        QtMocHelpers::PropertyData<ShutterModes>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'GrabModes'
        QtMocHelpers::EnumData<GrabModes>(25, 28, QMC::EnumIsFlag).add({
            {   29, GrabMode::NoGrabModes },
            {   30, GrabMode::AllScreens },
            {   31, GrabMode::CurrentScreen },
            {   32, GrabMode::ActiveWindow },
            {   33, GrabMode::WindowUnderCursor },
            {   34, GrabMode::TransientWithParent },
            {   35, GrabMode::AllScreensScaled },
            {   36, GrabMode::PerScreenImageNative },
        }),
        // flag 'ShutterModes'
        QtMocHelpers::EnumData<ShutterModes>(27, 37, QMC::EnumIsFlag).add({
            {   38, ShutterMode::Immediate },
            {   39, ShutterMode::OnClick },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ImagePlatform, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ImagePlatform::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ImagePlatformE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ImagePlatformE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ImagePlatformE_t>.metaTypes,
    nullptr
} };

void ImagePlatform::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImagePlatform *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->supportedGrabModesChanged(); break;
        case 1: _t->newScreenshotTaken((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 2: _t->newScreenshotTaken(); break;
        case 3: _t->newCroppableScreenshotTaken((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 4: _t->newScreenshotFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->newScreenshotFailed(); break;
        case 6: _t->newScreenshotCanceled(); break;
        case 7: _t->doGrab((*reinterpret_cast<std::add_pointer_t<ImagePlatform::ShutterMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ImagePlatform::GrabMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImagePlatform::*)()>(_a, &ImagePlatform::supportedGrabModesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImagePlatform::*)(const QImage & )>(_a, &ImagePlatform::newScreenshotTaken, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImagePlatform::*)(const QImage & )>(_a, &ImagePlatform::newCroppableScreenshotTaken, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImagePlatform::*)(const QString & )>(_a, &ImagePlatform::newScreenshotFailed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImagePlatform::*)()>(_a, &ImagePlatform::newScreenshotCanceled, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::assignFlags<GrabModes>(_v, _t->supportedGrabModes()); break;
        case 1: QtMocHelpers::assignFlags<ShutterModes>(_v, _t->supportedShutterModes()); break;
        default: break;
        }
    }
}

const QMetaObject *ImagePlatform::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImagePlatform::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ImagePlatformE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ImagePlatform::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ImagePlatform::supportedGrabModesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImagePlatform::newScreenshotTaken(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 3
void ImagePlatform::newCroppableScreenshotTaken(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ImagePlatform::newScreenshotFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 6
void ImagePlatform::newScreenshotCanceled()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
