/****************************************************************************
** Meta object code from reading C++ file 'ExportManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/ExportManager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ExportManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ExportManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ExportManager::qt_create_metaobjectdata<qt_meta_tag_ZN13ExportManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ExportManager",
        "imageChanged",
        "",
        "errorMessage",
        "str",
        "imageExported",
        "ExportManager::Actions",
        "actions",
        "QUrl",
        "url",
        "videoExported",
        "qrCodeScanned",
        "QVariant",
        "content",
        "Action",
        "NoActions",
        "Save",
        "SaveAs",
        "CopyImage",
        "CopyPath",
        "UserAction",
        "AnySave",
        "AnyAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'imageExported'
        QtMocHelpers::SignalData<void(const ExportManager::Actions &, const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'imageExported'
        QtMocHelpers::SignalData<void(const ExportManager::Actions &)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'videoExported'
        QtMocHelpers::SignalData<void(const ExportManager::Actions &, const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'videoExported'
        QtMocHelpers::SignalData<void(const ExportManager::Actions &)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'qrCodeScanned'
        QtMocHelpers::SignalData<void(const QVariant &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Action'
        QtMocHelpers::EnumData<enum Action>(14, 14, QMC::EnumFlags{}).add({
            {   15, Action::NoActions },
            {   16, Action::Save },
            {   17, Action::SaveAs },
            {   18, Action::CopyImage },
            {   19, Action::CopyPath },
            {   20, Action::UserAction },
            {   21, Action::AnySave },
            {   22, Action::AnyAction },
        }),
    };
    return QtMocHelpers::metaObjectData<ExportManager, qt_meta_tag_ZN13ExportManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ExportManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ExportManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ExportManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ExportManagerE_t>.metaTypes,
    nullptr
} };

void ExportManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ExportManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->imageChanged(); break;
        case 1: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->imageExported((*reinterpret_cast<std::add_pointer_t<ExportManager::Actions>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 3: _t->imageExported((*reinterpret_cast<std::add_pointer_t<ExportManager::Actions>>(_a[1]))); break;
        case 4: _t->videoExported((*reinterpret_cast<std::add_pointer_t<ExportManager::Actions>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 5: _t->videoExported((*reinterpret_cast<std::add_pointer_t<ExportManager::Actions>>(_a[1]))); break;
        case 6: _t->qrCodeScanned((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ExportManager::*)()>(_a, &ExportManager::imageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExportManager::*)(const QString & )>(_a, &ExportManager::errorMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExportManager::*)(const ExportManager::Actions & , const QUrl & )>(_a, &ExportManager::imageExported, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExportManager::*)(const ExportManager::Actions & , const QUrl & )>(_a, &ExportManager::videoExported, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExportManager::*)(const QVariant & )>(_a, &ExportManager::qrCodeScanned, 6))
            return;
    }
}

const QMetaObject *ExportManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ExportManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ExportManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ExportManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ExportManager::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ExportManager::errorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ExportManager::imageExported(const ExportManager::Actions & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 4
void ExportManager::videoExported(const ExportManager::Actions & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 6
void ExportManager::qrCodeScanned(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
