/****************************************************************************
** Meta object code from reading C++ file 'VideoPlatform.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Platforms/VideoPlatform.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'VideoPlatform.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13VideoPlatformE_t {};
} // unnamed namespace

template <> constexpr inline auto VideoPlatform::qt_create_metaobjectdata<qt_meta_tag_ZN13VideoPlatformE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VideoPlatform",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Created by SpectacleCore",
        "supportedRecordingModesChanged",
        "",
        "supportedFormatsChanged",
        "recordingSaved",
        "QUrl",
        "fileUrl",
        "recordingFailed",
        "message",
        "recordingCanceled",
        "recordedTimeChanged",
        "recordingStateChanged",
        "RecordingState",
        "state",
        "regionRequested",
        "startRecording",
        "VideoPlatform::RecordingMode",
        "recordingMode",
        "QVariantMap",
        "options",
        "includePointer",
        "finishRecording",
        "formatForPath",
        "Format",
        "path",
        "supportedRecordingModes",
        "RecordingModes",
        "supportedFormats",
        "Formats",
        "recordedTime",
        "isRecording",
        "recordingState",
        "RecordingMode",
        "NoRecordingModes",
        "Screen",
        "Window",
        "Region",
        "NotRecording",
        "Recording",
        "Rendering",
        "Finished",
        "NoFormat",
        "WebM_VP9",
        "MP4_H264",
        "WebP",
        "Gif",
        "DefaultFormat"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'supportedRecordingModesChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedFormatsChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recordingSaved'
        QtMocHelpers::SignalData<void(const QUrl &)>(10, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'recordingFailed'
        QtMocHelpers::SignalData<void(const QString &)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'recordingCanceled'
        QtMocHelpers::SignalData<void(const QString &)>(15, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'recordedTimeChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recordingStateChanged'
        QtMocHelpers::SignalData<void(enum RecordingState)>(17, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'regionRequested'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startRecording'
        QtMocHelpers::SlotData<void(const QUrl &, VideoPlatform::RecordingMode, const QVariantMap &, bool)>(21, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'finishRecording'
        QtMocHelpers::SlotData<void()>(27, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'formatForPath'
        QtMocHelpers::MethodData<enum Format(const QString &)>(28, 8, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'supportedRecordingModes'
        QtMocHelpers::PropertyData<RecordingModes>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'supportedFormats'
        QtMocHelpers::PropertyData<Formats>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'recordedTime'
        QtMocHelpers::PropertyData<qint64>(35, QMetaType::LongLong, QMC::DefaultPropertyFlags, 5),
        // property 'isRecording'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'recordingState'
        QtMocHelpers::PropertyData<enum RecordingState>(37, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RecordingMode'
        QtMocHelpers::EnumData<enum RecordingMode>(38, 38, QMC::EnumFlags{}).add({
            {   39, RecordingMode::NoRecordingModes },
            {   40, RecordingMode::Screen },
            {   41, RecordingMode::Window },
            {   42, RecordingMode::Region },
        }),
        // enum 'RecordingState'
        QtMocHelpers::EnumData<enum RecordingState>(18, 18, QMC::EnumIsScoped).add({
            {   43, RecordingState::NotRecording },
            {   44, RecordingState::Recording },
            {   45, RecordingState::Rendering },
            {   46, RecordingState::Finished },
        }),
        // enum 'Format'
        QtMocHelpers::EnumData<enum Format>(29, 29, QMC::EnumFlags{}).add({
            {   47, Format::NoFormat },
            {   48, Format::WebM_VP9 },
            {   49, Format::MP4_H264 },
            {   50, Format::WebP },
            {   51, Format::Gif },
            {   52, Format::DefaultFormat },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<VideoPlatform, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject VideoPlatform::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13VideoPlatformE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13VideoPlatformE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13VideoPlatformE_t>.metaTypes,
    nullptr
} };

void VideoPlatform::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VideoPlatform *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->supportedRecordingModesChanged(); break;
        case 1: _t->supportedFormatsChanged(); break;
        case 2: _t->recordingSaved((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->recordingFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->recordingCanceled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->recordedTimeChanged(); break;
        case 6: _t->recordingStateChanged((*reinterpret_cast<std::add_pointer_t<enum RecordingState>>(_a[1]))); break;
        case 7: _t->regionRequested(); break;
        case 8: _t->startRecording((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<VideoPlatform::RecordingMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 9: _t->finishRecording(); break;
        case 10: { enum Format _r = _t->formatForPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<enum Format*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)()>(_a, &VideoPlatform::supportedRecordingModesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)()>(_a, &VideoPlatform::supportedFormatsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)(const QUrl & )>(_a, &VideoPlatform::recordingSaved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)(const QString & )>(_a, &VideoPlatform::recordingFailed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)(const QString & )>(_a, &VideoPlatform::recordingCanceled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)()>(_a, &VideoPlatform::recordedTimeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)(RecordingState )>(_a, &VideoPlatform::recordingStateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoPlatform::*)()>(_a, &VideoPlatform::regionRequested, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<RecordingModes*>(_v) = _t->supportedRecordingModes(); break;
        case 1: *reinterpret_cast<Formats*>(_v) = _t->supportedFormats(); break;
        case 2: *reinterpret_cast<qint64*>(_v) = _t->recordedTime(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isRecording(); break;
        case 4: *reinterpret_cast<enum RecordingState*>(_v) = _t->recordingState(); break;
        default: break;
        }
    }
}

const QMetaObject *VideoPlatform::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VideoPlatform::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13VideoPlatformE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int VideoPlatform::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void VideoPlatform::supportedRecordingModesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void VideoPlatform::supportedFormatsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void VideoPlatform::recordingSaved(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void VideoPlatform::recordingFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void VideoPlatform::recordingCanceled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void VideoPlatform::recordedTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void VideoPlatform::recordingStateChanged(RecordingState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void VideoPlatform::regionRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
