/****************************************************************************
** Meta object code from reading C++ file 'InlineMessageModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Gui/InlineMessageModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'InlineMessageModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18InlineMessageModelE_t {};
} // unnamed namespace

template <> constexpr inline auto InlineMessageModel::qt_create_metaobjectdata<qt_meta_tag_ZN18InlineMessageModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InlineMessageModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "countChanged",
        "",
        "push",
        "InlineMessageType",
        "type",
        "text",
        "QVariant",
        "data",
        "pop",
        "row",
        "clear",
        "copyToClipboard",
        "content",
        "openContainingFolder",
        "QUrl",
        "url",
        "count",
        "CustomRoles",
        "TypeRole",
        "DataRole",
        "Error",
        "Warning",
        "InformationalType",
        "Copied",
        "Saved",
        "Shared",
        "Scanned"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'push'
        QtMocHelpers::MethodData<void(enum InlineMessageType, const QString &, const QVariant &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Method 'push'
        QtMocHelpers::MethodData<void(enum InlineMessageType, const QString &)>(7, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
        }}),
        // Method 'pop'
        QtMocHelpers::MethodData<void(int)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Method 'pop'
        QtMocHelpers::MethodData<void()>(13, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyToClipboard'
        QtMocHelpers::MethodData<void(const QVariant &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 17 },
        }}),
        // Method 'openContainingFolder'
        QtMocHelpers::MethodData<void(const QUrl &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CustomRoles'
        QtMocHelpers::EnumData<enum CustomRoles>(22, 22, QMC::EnumFlags{}).add({
            {   23, CustomRoles::TypeRole },
            {   24, CustomRoles::DataRole },
        }),
        // enum 'InlineMessageType'
        QtMocHelpers::EnumData<enum InlineMessageType>(8, 8, QMC::EnumFlags{}).add({
            {   25, InlineMessageType::Error },
            {   26, InlineMessageType::Warning },
            {   27, InlineMessageType::InformationalType },
            {   28, InlineMessageType::Copied },
            {   29, InlineMessageType::Saved },
            {   30, InlineMessageType::Shared },
            {   31, InlineMessageType::Scanned },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<InlineMessageModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InlineMessageModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InlineMessageModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InlineMessageModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18InlineMessageModelE_t>.metaTypes,
    nullptr
} };

void InlineMessageModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InlineMessageModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->push((*reinterpret_cast<std::add_pointer_t<enum InlineMessageType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 2: _t->push((*reinterpret_cast<std::add_pointer_t<enum InlineMessageType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->pop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->pop(); break;
        case 5: _t->clear(); break;
        case 6: _t->copyToClipboard((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 7: _t->openContainingFolder((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InlineMessageModel::*)()>(_a, &InlineMessageModel::countChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        default: break;
        }
    }
}

const QMetaObject *InlineMessageModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InlineMessageModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InlineMessageModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int InlineMessageModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void InlineMessageModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
