/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0x69,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xe2,0x7,0xfd,0x12,0x0,0x56,0xd8,0x46,0x1e,0x30,0x55,0x73,
  0xff,0x5f,0x79,0xed,0x96,0x52,0x9e,0x22,0x91,0x13,0x3e,0xa8,0xaa,0x6a,0x5,0x0,
  0x0,0xf9,0xa7,0xe6,0x52,0x85,0x11,0x29,0x31,0xac,0x2,0x3f,0x0,0x3e,0x0,0x3d,
  0x0,0x86,0x86,0x5f,0xcb,0x20,0x51,0x14,0x75,0xd6,0xa1,0x5a,0x64,0x8a,0x6a,0xf,
  0x55,0x98,0xe2,0x37,0x8f,0x50,0xea,0x2c,0x37,0x29,0x8f,0x8c,0x68,0xca,0x24,0xd9,
  0x1e,0x9e,0x49,0xf2,0x55,0x9e,0x89,0x37,0xeb,0xe,0x45,0x2d,0xbd,0xf5,0xe3,0x22,
  0x4,0xfc,0x2d,0xed,0x75,0x28,0x1,0x67,0x1d,0x40,0x8b,0x3c,0xfd,0x4d,0xc6,0x55,
  0x7d,0x8b,0x48,0x5f,0xfc,0xa7,0x9a,0x8f,0x11,0xf2,0x8c,0x21,0x8f,0xb3,0xe1,0xfb,
  0x5a,0x45,0x30,0x17,0x19,0xcb,0xdd,0xf3,0x20,0x7b,0xdf,0xcb,0x88,0xa8,0x87,0xc7,
  0x7c,0x91,0x50,0xc2,0xed,0x98,0x42,0x9b,0x37,0x9e,0x29,0x3f,0xd8,0x5b,0x2b,0xb7,
  0x6,0x89,0x72,0x93,0x31,0x5,0x0,0x3,0x82,0x60,0x5a,0x76,0xbd,0x2,0x8f,0x37,
  0x95,0xf2,0x90,0xaf,0x7b,0xeb,0x80,0xef,0x7f,0x6c,0xb5,0xc1,0x76,0x72,0x6c,0x9d,
  0xa5,0x7,0xe5,0xb7,0x98,0x7b,0x48,0x47,0x86,0x21,0x51,0xc3,0xaa,0xe9,0xa4,0xf1,
  0x53,0x17,0xe2,0xc3,0x3a,0x68,0x11,0xe9,0xfb,0xd7,0xbd,0x9e,0x12,0x76,0x8e,0xd4,
  0x84,0x2e,0x7e,0xbc,0x69,0xe5,0x10,0x41,0x6e,0xeb,0x3a,0x52,0x3c,0x9c,0x1c,0x19,
  0xcc,0x5e,0x61,0xb6,0x98,0x6f,0xe8,0x5d,0xa3,0x8f,0x8f,0x5c,0x87,0x7e,0x91,0x3d,
  0x57,0x47,0xe6,0xc8,0x7f,0xd4,0x2,0xba,0xcb,0xb0,0xc8,0xeb,0x15,0xf9,0x5c,0x63,
  0x5e,0x45,0xf9,0x6b,0xeb,0x64,0x5c,0x92,0x66,0x8e,0xdc,0x3f,0x2e,0xb,0xe8,0x91,
  0xbb,0x8d,0xdb,0xa6,0x90,0x96,0x2e,0x80,0xa0,0xa8,0xc1,0x8a,0xc8,0xc8,0xc8,0x48,
  0x92,0x82,0x64,0x59,0x3,0x20,0x46,0x40,0x20,0x56,0xd4,0x1,0x21,0x14,0x6,0x32,
  0xc4,0x20,0xc8,0xc,0x34,0x62,0x52,0x90,0x14,0x56,0xda,0xc,0x9,0x75,0x7c,0x85,
  0x43,0x28,0x45,0xee,0xb6,0xc7,0x25,0x83,0x49,0x16,0xac,0x53,0xd1,0xaa,0x29,0xd4,
  0x67,0x14,0x68,0xb7,0x10,0x17,0x1c,0x3b,0x24,0xec,0x69,0x11,0x4b,0x1,0xbf,0x3f,
  0x58,0x9d,0x64,0xce,0xb1,0x56,0x72,0xaf,0xc7,0xc9,0xc9,0xd5,0xa1,0x93,0x19,0x13,
  0x64,0x53,0x20,0xca,0x3a,0x54,0x16,0xa9,0x78,0x96,0xf0,0x21,0xf4,0x2c,0x77,0xd7,
  0x15,0x33,0x53,0xad,0xdf,0x86,0x4c,0xa7,0xbc,0xe1,0xfc,0x7,0x92,0xa0,0x5c,0x99,
  0xff,0x2e,0xea,0xa8,0xa3,0x91,0x2a,0x21,0xbf,0x16,0xac,0xa5,0x36,0x21,0xea,0xcb,
  0xa1,0x4d,0x84,0xcf,0xb3,0xe8,0x9c,0x23,0x63,0x1e,0x5d,0xff,0x6f,0xd3,0xdc,0x30,
  0xa4,0x50,0x26,0xce,0xbc,0xa0,0xdd,0xad,0x50,0x30,0x33,0xec,0x62,0x9c,0x55,0x1a,
  0x8f,0x2f,0x4a,0x62,0x6d,0xcf,0xae,0x25,0x79,0x36,0x3b,0xbf,0x5e,0xe1,0x7,0x4,
  0x1d,0x2a,0xd1,0xed,0x99,0x42,0xf0,0xcb,0xfd,0x16,0x1,0x72,0xeb,0xf9,0x5e,0x36,
  0xab,0xae,0x9e,0x18,0x64,0xf7,0x7c,0xca,0xee,0x9d,0x5b,0xa5,0x3e,0x3f,0x34,0x96,
  0x1a,0x63,0x92,0x9d,0x7,0xdd,0x42,0x32,0xab,0x49,0x4f,0x60,0x58,0xdb,0xad,0x63,
  0x65,0x71,0x7b,0xe0,0x28,0xec,0x69,0x36,0x8e,0x36,0x1f,0x0,0xb3,0x9e,0x86,0x3b,
  0x1,0x43,0x8,0xc,0xb8,0xe5,0x3d,0xc4,0xe0,0xbc,0x54,0xb7,0xf,0x86,0xe6,0xdc,
  0xf5,0xf6,0xe2,0xb7,0xd8,0x3a,0x67,0x7f,0x66,0xe7,0xc3,0x65,0xbd,0x4a,0xf,0x50,
  0x9a,0x74,0x72,0xe4,0x26,0xc2,0x10,0x49,0x99,0x99,0xab,0xeb,0x18,0x7d,0xe8,0x9,
  0x9f,0x66,0x1e,0x5b,0xbc,0x7e,0x4b,0xd2,0x2c,0x15,0x85,0xc9,0x9b,0xe,0xc9,0x1d,
  0x3f,0x51,0xa9,0x34,0x1e,0x79,0xf7,0xaa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // spectacle
  0x0,0x9,
  0xb,0xaa,0x8e,0xe5,
  0x0,0x73,
  0x0,0x70,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x61,0x0,0x63,0x0,0x6c,0x0,0x65,
    // private
  0x0,0x7,
  0x7,0x90,0xc8,0x45,
  0x0,0x70,
  0x0,0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,0x74,0x0,0x65,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,
  // :/qt/qml/org/kde/spectacle
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,
  // :/qt/qml/org/kde/spectacle/private
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,
  // :/qt/qml/org/kde/spectacle/private/qmldir
  0x0,0x0,0x0,0x5a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0x27,0xa8,0xcb,0x10,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
