/****************************************************************************
** Meta object code from reading C++ file 'Selection.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Gui/Selection.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Selection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9SelectionE_t {};
} // unnamed namespace

template <> constexpr inline auto Selection::qt_create_metaobjectdata<qt_meta_tag_ZN9SelectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Selection",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Created by SelectionEditor",
        "xChanged",
        "",
        "yChanged",
        "widthChanged",
        "heightChanged",
        "leftChanged",
        "topChanged",
        "rightChanged",
        "bottomChanged",
        "horizontalCenterChanged",
        "verticalCenterChanged",
        "rectChanged",
        "sizeChanged",
        "emptyChanged",
        "x",
        "y",
        "width",
        "height",
        "left",
        "top",
        "right",
        "bottom",
        "horizontalCenter",
        "verticalCenter",
        "rect",
        "QRectF",
        "size",
        "QSizeF",
        "empty"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalCenterChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verticalCenterChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rectChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emptyChanged'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(21, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(22, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'width'
        QtMocHelpers::PropertyData<qreal>(23, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'height'
        QtMocHelpers::PropertyData<qreal>(24, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'left'
        QtMocHelpers::PropertyData<qreal>(25, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'top'
        QtMocHelpers::PropertyData<qreal>(26, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'right'
        QtMocHelpers::PropertyData<qreal>(27, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'bottom'
        QtMocHelpers::PropertyData<qreal>(28, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'horizontalCenter'
        QtMocHelpers::PropertyData<qreal>(29, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8),
        // property 'verticalCenter'
        QtMocHelpers::PropertyData<qreal>(30, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 9),
        // property 'rect'
        QtMocHelpers::PropertyData<QRectF>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 10),
        // property 'size'
        QtMocHelpers::PropertyData<QSizeF>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 11),
        // property 'empty'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Selection, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Selection::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SelectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SelectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9SelectionE_t>.metaTypes,
    nullptr
} };

void Selection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Selection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->xChanged(); break;
        case 1: _t->yChanged(); break;
        case 2: _t->widthChanged(); break;
        case 3: _t->heightChanged(); break;
        case 4: _t->leftChanged(); break;
        case 5: _t->topChanged(); break;
        case 6: _t->rightChanged(); break;
        case 7: _t->bottomChanged(); break;
        case 8: _t->horizontalCenterChanged(); break;
        case 9: _t->verticalCenterChanged(); break;
        case 10: _t->rectChanged(); break;
        case 11: _t->sizeChanged(); break;
        case 12: _t->emptyChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::xChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::yChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::widthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::heightChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::leftChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::topChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::rightChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::bottomChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::horizontalCenterChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::verticalCenterChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::rectChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::sizeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Selection::*)()>(_a, &Selection::emptyChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->width(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->height(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->left(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->top(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->right(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->bottom(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->horizontalCenter(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->verticalCenter(); break;
        case 10: *reinterpret_cast<QRectF*>(_v) = _t->rectF(); break;
        case 11: *reinterpret_cast<QSizeF*>(_v) = _t->sizeF(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isEmpty(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setX(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setY(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setLeft(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setTop(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setRight(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setBottom(*reinterpret_cast<qreal*>(_v)); break;
        case 8: _t->setHorizontalCenter(*reinterpret_cast<qreal*>(_v)); break;
        case 9: _t->setVerticalCenter(*reinterpret_cast<qreal*>(_v)); break;
        case 10: _t->setRect(*reinterpret_cast<QRectF*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Selection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Selection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SelectionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Selection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Selection::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Selection::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Selection::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Selection::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Selection::leftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Selection::topChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Selection::rightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Selection::bottomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Selection::horizontalCenterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Selection::verticalCenterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Selection::rectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Selection::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Selection::emptyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
