/****************************************************************************
** Meta object code from reading C++ file 'PlatformNull.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Platforms/PlatformNull.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PlatformNull.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ImagePlatformNullE_t {};
} // unnamed namespace

template <> constexpr inline auto ImagePlatformNull::qt_create_metaobjectdata<qt_meta_tag_ZN17ImagePlatformNullE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImagePlatformNull",
        "doGrab",
        "",
        "ImagePlatform::ShutterMode",
        "shutterMode",
        "ImagePlatform::GrabMode",
        "grabMode",
        "includePointer",
        "includeDecorations",
        "includeShadow"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doGrab'
        QtMocHelpers::SlotData<void(ImagePlatform::ShutterMode, ImagePlatform::GrabMode, bool, bool, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::Bool, 7 }, { QMetaType::Bool, 8 },
            { QMetaType::Bool, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImagePlatformNull, qt_meta_tag_ZN17ImagePlatformNullE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImagePlatformNull::staticMetaObject = { {
    QMetaObject::SuperData::link<ImagePlatform::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ImagePlatformNullE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ImagePlatformNullE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ImagePlatformNullE_t>.metaTypes,
    nullptr
} };

void ImagePlatformNull::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImagePlatformNull *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doGrab((*reinterpret_cast<std::add_pointer_t<ImagePlatform::ShutterMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ImagePlatform::GrabMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        default: ;
        }
    }
}

const QMetaObject *ImagePlatformNull::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImagePlatformNull::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ImagePlatformNullE_t>.strings))
        return static_cast<void*>(this);
    return ImagePlatform::qt_metacast(_clname);
}

int ImagePlatformNull::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ImagePlatform::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN17VideoPlatformNullE_t {};
} // unnamed namespace

template <> constexpr inline auto VideoPlatformNull::qt_create_metaobjectdata<qt_meta_tag_ZN17VideoPlatformNullE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VideoPlatformNull"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VideoPlatformNull, qt_meta_tag_ZN17VideoPlatformNullE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VideoPlatformNull::staticMetaObject = { {
    QMetaObject::SuperData::link<VideoPlatform::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17VideoPlatformNullE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17VideoPlatformNullE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17VideoPlatformNullE_t>.metaTypes,
    nullptr
} };

void VideoPlatformNull::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VideoPlatformNull *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *VideoPlatformNull::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VideoPlatformNull::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17VideoPlatformNullE_t>.strings))
        return static_cast<void*>(this);
    return VideoPlatform::qt_metacast(_clname);
}

int VideoPlatformNull::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VideoPlatform::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
