/****************************************************************************
** Meta object code from reading C++ file 'SpectacleWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Gui/SpectacleWindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SpectacleWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SpectacleWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto SpectacleWindow::qt_create_metaobjectdata<qt_meta_tag_ZN15SpectacleWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpectacleWindow",
        "annotatingChanged",
        "",
        "logicalXChanged",
        "logicalYChanged",
        "devicePixelRatioChanged",
        "save",
        "saveAs",
        "copyImage",
        "copyLocation",
        "showPrintDialog",
        "showPreferencesDialog",
        "showFontDialog",
        "showColorDialog",
        "option",
        "dprRound",
        "value",
        "QPointF",
        "point",
        "dprCeil",
        "dprFloor",
        "baseFileName",
        "QUrl",
        "url",
        "annotating",
        "logicalX",
        "logicalY",
        "devicePixelRatio"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'annotatingChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logicalXChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logicalYChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'devicePixelRatioChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyImage'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyLocation'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPrintDialog'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPreferencesDialog'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showFontDialog'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showColorDialog'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Method 'dprRound'
        QtMocHelpers::MethodData<qreal(qreal) const>(15, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 16 },
        }}),
        // Method 'dprRound'
        QtMocHelpers::MethodData<QPointF(const QPointF &) const>(15, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'dprCeil'
        QtMocHelpers::MethodData<qreal(qreal) const>(19, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 16 },
        }}),
        // Method 'dprFloor'
        QtMocHelpers::MethodData<qreal(qreal) const>(20, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 16 },
        }}),
        // Method 'baseFileName'
        QtMocHelpers::MethodData<QString(const QUrl &) const>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'annotating'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'logicalX'
        QtMocHelpers::PropertyData<qreal>(25, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'logicalY'
        QtMocHelpers::PropertyData<qreal>(26, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'devicePixelRatio'
        QtMocHelpers::PropertyData<qreal>(27, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpectacleWindow, qt_meta_tag_ZN15SpectacleWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SpectacleWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpectacleWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpectacleWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SpectacleWindowE_t>.metaTypes,
    nullptr
} };

void SpectacleWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpectacleWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->annotatingChanged(); break;
        case 1: _t->logicalXChanged(); break;
        case 2: _t->logicalYChanged(); break;
        case 3: _t->devicePixelRatioChanged(); break;
        case 4: _t->save(); break;
        case 5: _t->saveAs(); break;
        case 6: _t->copyImage(); break;
        case 7: _t->copyLocation(); break;
        case 8: _t->showPrintDialog(); break;
        case 9: _t->showPreferencesDialog(); break;
        case 10: _t->showFontDialog(); break;
        case 11: _t->showColorDialog((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: { qreal _r = _t->dprRound((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 13: { QPointF _r = _t->dprRound((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 14: { qreal _r = _t->dprCeil((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 15: { qreal _r = _t->dprFloor((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->baseFileName((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SpectacleWindow::*)()>(_a, &SpectacleWindow::annotatingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleWindow::*)()>(_a, &SpectacleWindow::logicalXChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleWindow::*)()>(_a, &SpectacleWindow::logicalYChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleWindow::*)()>(_a, &SpectacleWindow::devicePixelRatioChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isAnnotating(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->logicalX(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->logicalY(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->effectiveDevicePixelRatio(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAnnotating(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SpectacleWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpectacleWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpectacleWindowE_t>.strings))
        return static_cast<void*>(this);
    return QQuickView::qt_metacast(_clname);
}

int SpectacleWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SpectacleWindow::annotatingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SpectacleWindow::logicalXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SpectacleWindow::logicalYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SpectacleWindow::devicePixelRatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
