/****************************************************************************
** Meta object code from reading C++ file 'SpectacleDBusAdapter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/SpectacleDBusAdapter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SpectacleDBusAdapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20SpectacleDBusAdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto SpectacleDBusAdapter::qt_create_metaobjectdata<qt_meta_tag_ZN20SpectacleDBusAdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpectacleDBusAdapter",
        "D-Bus Interface",
        "org.kde.Spectacle",
        "ScreenshotTaken",
        "",
        "fileName",
        "ScreenshotFailed",
        "message",
        "RecordingTaken",
        "RecordingFailed",
        "FullScreen",
        "Q_NOREPLY",
        "includeMousePointer",
        "CurrentScreen",
        "ActiveWindow",
        "includeWindowDecorations",
        "includeWindowShadow",
        "WindowUnderCursor",
        "RectangularRegion",
        "RecordRegion",
        "RecordScreen",
        "RecordWindow",
        "OpenWithoutScreenshot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ScreenshotTaken'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'ScreenshotFailed'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'RecordingTaken'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'RecordingFailed'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'FullScreen'
        QtMocHelpers::SlotData<void(int)>(10, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'CurrentScreen'
        QtMocHelpers::SlotData<void(int)>(13, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'ActiveWindow'
        QtMocHelpers::SlotData<void(int, int, int)>(14, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 12 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'WindowUnderCursor'
        QtMocHelpers::SlotData<void(int, int, int)>(17, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 12 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'RectangularRegion'
        QtMocHelpers::SlotData<void(int)>(18, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'RecordRegion'
        QtMocHelpers::SlotData<void(int)>(19, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'RecordScreen'
        QtMocHelpers::SlotData<void(int)>(20, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'RecordWindow'
        QtMocHelpers::SlotData<void(int)>(21, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'OpenWithoutScreenshot'
        QtMocHelpers::SlotData<void()>(22, 11, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SpectacleDBusAdapter, qt_meta_tag_ZN20SpectacleDBusAdapterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SpectacleDBusAdapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SpectacleDBusAdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SpectacleDBusAdapterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20SpectacleDBusAdapterE_t>.metaTypes,
    nullptr
} };

void SpectacleDBusAdapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpectacleDBusAdapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ScreenshotTaken((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ScreenshotFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->RecordingTaken((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->RecordingFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->FullScreen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->CurrentScreen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->ActiveWindow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->WindowUnderCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->RectangularRegion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->RecordRegion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->RecordScreen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->RecordWindow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->OpenWithoutScreenshot(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SpectacleDBusAdapter::*)(const QString & )>(_a, &SpectacleDBusAdapter::ScreenshotTaken, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleDBusAdapter::*)(const QString & )>(_a, &SpectacleDBusAdapter::ScreenshotFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleDBusAdapter::*)(const QString & )>(_a, &SpectacleDBusAdapter::RecordingTaken, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpectacleDBusAdapter::*)(const QString & )>(_a, &SpectacleDBusAdapter::RecordingFailed, 3))
            return;
    }
}

const QMetaObject *SpectacleDBusAdapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpectacleDBusAdapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SpectacleDBusAdapterE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SpectacleDBusAdapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void SpectacleDBusAdapter::ScreenshotTaken(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SpectacleDBusAdapter::ScreenshotFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SpectacleDBusAdapter::RecordingTaken(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SpectacleDBusAdapter::RecordingFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
