/********************************************************************************
** Form generated from reading UI file 'ImageSaveOptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGESAVEOPTIONS_H
#define UI_IMAGESAVEOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ImageSaveOptions
{
public:
    QFormLayout *formLayout;
    QLabel *saveLocationLabel;
    KUrlRequester *kcfg_imageSaveLocation;
    QLabel *qualityLabel;
    QHBoxLayout *qualityHLayout;
    QVBoxLayout *qualityVLayout;
    QSlider *kcfg_imageCompressionQuality;
    QLabel *imageCompressionQualityHelpLable;
    QSpinBox *qualitySpinner;
    QLabel *filenameLabel;
    QHBoxLayout *saveLayout;
    QLineEdit *kcfg_imageFilenameTemplate;
    QComboBox *kcfg_preferredImageFormat;
    QLabel *PreviewLabel;
    QLabel *preview;
    QLabel *captureInstructionLabel;

    void setupUi(QWidget *ImageSaveOptions)
    {
        if (ImageSaveOptions->objectName().isEmpty())
            ImageSaveOptions->setObjectName("ImageSaveOptions");
        formLayout = new QFormLayout(ImageSaveOptions);
        formLayout->setObjectName("formLayout");
        saveLocationLabel = new QLabel(ImageSaveOptions);
        saveLocationLabel->setObjectName("saveLocationLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, saveLocationLabel);

        kcfg_imageSaveLocation = new KUrlRequester(ImageSaveOptions);
        kcfg_imageSaveLocation->setObjectName("kcfg_imageSaveLocation");
        kcfg_imageSaveLocation->setMode(KFile::Directory|KFile::LocalOnly);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_imageSaveLocation);

        qualityLabel = new QLabel(ImageSaveOptions);
        qualityLabel->setObjectName("qualityLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, qualityLabel);

        qualityHLayout = new QHBoxLayout();
        qualityHLayout->setObjectName("qualityHLayout");
        qualityVLayout = new QVBoxLayout();
        qualityVLayout->setSpacing(0);
        qualityVLayout->setObjectName("qualityVLayout");
        kcfg_imageCompressionQuality = new QSlider(ImageSaveOptions);
        kcfg_imageCompressionQuality->setObjectName("kcfg_imageCompressionQuality");
        kcfg_imageCompressionQuality->setMaximum(100);
        kcfg_imageCompressionQuality->setOrientation(Qt::Horizontal);

        qualityVLayout->addWidget(kcfg_imageCompressionQuality);

        imageCompressionQualityHelpLable = new QLabel(ImageSaveOptions);
        imageCompressionQualityHelpLable->setObjectName("imageCompressionQualityHelpLable");

        qualityVLayout->addWidget(imageCompressionQualityHelpLable, 0, Qt::AlignTop);


        qualityHLayout->addLayout(qualityVLayout);

        qualitySpinner = new QSpinBox(ImageSaveOptions);
        qualitySpinner->setObjectName("qualitySpinner");
        qualitySpinner->setMaximum(100);

        qualityHLayout->addWidget(qualitySpinner, 0, Qt::AlignTop);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, qualityHLayout);

        filenameLabel = new QLabel(ImageSaveOptions);
        filenameLabel->setObjectName("filenameLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, filenameLabel);

        saveLayout = new QHBoxLayout();
        saveLayout->setObjectName("saveLayout");
        kcfg_imageFilenameTemplate = new QLineEdit(ImageSaveOptions);
        kcfg_imageFilenameTemplate->setObjectName("kcfg_imageFilenameTemplate");
        kcfg_imageFilenameTemplate->setPlaceholderText(QString::fromUtf8("%d"));

        saveLayout->addWidget(kcfg_imageFilenameTemplate);

        kcfg_preferredImageFormat = new QComboBox(ImageSaveOptions);
        kcfg_preferredImageFormat->setObjectName("kcfg_preferredImageFormat");
        kcfg_preferredImageFormat->setProperty("kcfg_property", QVariant(QString::fromUtf8("currentText")));

        saveLayout->addWidget(kcfg_preferredImageFormat);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, saveLayout);

        PreviewLabel = new QLabel(ImageSaveOptions);
        PreviewLabel->setObjectName("PreviewLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, PreviewLabel);

        preview = new QLabel(ImageSaveOptions);
        preview->setObjectName("preview");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, preview);

        captureInstructionLabel = new QLabel(ImageSaveOptions);
        captureInstructionLabel->setObjectName("captureInstructionLabel");
        captureInstructionLabel->setTextFormat(Qt::RichText);
        captureInstructionLabel->setWordWrap(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, captureInstructionLabel);

#if QT_CONFIG(shortcut)
        saveLocationLabel->setBuddy(kcfg_imageSaveLocation);
        qualityLabel->setBuddy(qualitySpinner);
        filenameLabel->setBuddy(kcfg_imageFilenameTemplate);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ImageSaveOptions);
        QObject::connect(kcfg_imageCompressionQuality, &QSlider::valueChanged, qualitySpinner, &QSpinBox::setValue);
        QObject::connect(qualitySpinner, &QSpinBox::valueChanged, kcfg_imageCompressionQuality, &QSlider::setValue);

        QMetaObject::connectSlotsByName(ImageSaveOptions);
    } // setupUi

    void retranslateUi(QWidget *ImageSaveOptions)
    {
        saveLocationLabel->setText(tr2i18n("Save Location:", nullptr));
        qualityLabel->setText(tr2i18n("Compression Quality:", nullptr));
        imageCompressionQualityHelpLable->setText(tr2i18n("For lossy image formats like JPEG", nullptr));
        qualitySpinner->setSuffix(tr2i18n("%", nullptr));
        filenameLabel->setText(tr2i18n("Filename:", nullptr));
        PreviewLabel->setText(tr2i18n("Preview:", "Preview of the user configured filename"));
        preview->setText(QString());
        captureInstructionLabel->setText(QString());
        (void)ImageSaveOptions;
    } // retranslateUi

};

namespace Ui {
    class ImageSaveOptions: public Ui_ImageSaveOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGESAVEOPTIONS_H

