#ifndef SPECTACLE_CONFIG_H
#define SPECTACLE_CONFIG_H

/* Define to 1 if we are building with XCB */
#define XCB_FOUND 1

/* Define to 1 if we have Purpose */
#define PURPOSE_FOUND 1

/* Set the Spectacle version from CMake */
#define SPECTACLE_VERSION "6.6.90"

/* Set the QML module URI from CMake */
#define SPECTACLE_QML_URI "org.kde.spectacle.private"

/* Set the QML module URI from CMake */
static const auto SPECTACLE_QML_PATH = u"qrc:/qt/qml/org/kde/spectacle/private";

#endif
