/****************************************************************************
** Meta object code from reading C++ file 'settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../settings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8SettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto Settings::qt_create_metaobjectdata<qt_meta_tag_ZN8SettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Settings",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "launchActionChanged",
        "",
        "printKeyRunningActionChanged",
        "autoSaveImageChanged",
        "closeAfterOcrChanged",
        "clipboardGroupChanged",
        "useLightMaskColorChanged",
        "showMagnifierChanged",
        "useReleaseToCaptureChanged",
        "rememberSelectionRectChanged",
        "ocrLanguagesChanged",
        "selectionRectChanged",
        "captureOnClickChanged",
        "includePointerChanged",
        "videoIncludePointerChanged",
        "includeDecorationsChanged",
        "includeShadowChanged",
        "transientOnlyChanged",
        "quitAfterSaveCopyExportChanged",
        "captureDelayChanged",
        "captureModeChanged",
        "imageSaveLocationChanged",
        "imageCompressionQualityChanged",
        "preferredImageFormatChanged",
        "imageFilenameTemplateChanged",
        "lastImageSaveLocationChanged",
        "lastImageSaveAsLocationChanged",
        "videoSaveLocationChanged",
        "preferredVideoFormatChanged",
        "videoFilenameTemplateChanged",
        "lastVideoSaveLocationChanged",
        "lastVideoSaveAsLocationChanged",
        "launchAction",
        "isLaunchActionImmutable",
        "defaultLaunchActionValue",
        "printKeyRunningAction",
        "isPrintKeyRunningActionImmutable",
        "defaultPrintKeyRunningActionValue",
        "autoSaveImage",
        "isAutoSaveImageImmutable",
        "defaultAutoSaveImageValue",
        "closeAfterOcr",
        "isCloseAfterOcrImmutable",
        "defaultCloseAfterOcrValue",
        "clipboardGroup",
        "isClipboardGroupImmutable",
        "defaultClipboardGroupValue",
        "useLightMaskColor",
        "isUseLightMaskColorImmutable",
        "defaultUseLightMaskColorValue",
        "showMagnifier",
        "isShowMagnifierImmutable",
        "defaultShowMagnifierValue",
        "useReleaseToCapture",
        "isUseReleaseToCaptureImmutable",
        "defaultUseReleaseToCaptureValue",
        "rememberSelectionRect",
        "isRememberSelectionRectImmutable",
        "defaultRememberSelectionRectValue",
        "ocrLanguages",
        "isOcrLanguagesImmutable",
        "defaultOcrLanguagesValue",
        "selectionRect",
        "QRectF",
        "isSelectionRectImmutable",
        "defaultSelectionRectValue",
        "captureOnClick",
        "isCaptureOnClickImmutable",
        "defaultCaptureOnClickValue",
        "includePointer",
        "isIncludePointerImmutable",
        "defaultIncludePointerValue",
        "videoIncludePointer",
        "isVideoIncludePointerImmutable",
        "defaultVideoIncludePointerValue",
        "includeDecorations",
        "isIncludeDecorationsImmutable",
        "defaultIncludeDecorationsValue",
        "includeShadow",
        "isIncludeShadowImmutable",
        "defaultIncludeShadowValue",
        "transientOnly",
        "isTransientOnlyImmutable",
        "defaultTransientOnlyValue",
        "quitAfterSaveCopyExport",
        "isQuitAfterSaveCopyExportImmutable",
        "defaultQuitAfterSaveCopyExportValue",
        "captureDelay",
        "isCaptureDelayImmutable",
        "defaultCaptureDelayValue",
        "captureMode",
        "isCaptureModeImmutable",
        "defaultCaptureModeValue",
        "imageSaveLocation",
        "QUrl",
        "isImageSaveLocationImmutable",
        "defaultImageSaveLocationValue",
        "imageCompressionQuality",
        "isImageCompressionQualityImmutable",
        "defaultImageCompressionQualityValue",
        "preferredImageFormat",
        "isPreferredImageFormatImmutable",
        "defaultPreferredImageFormatValue",
        "imageFilenameTemplate",
        "isImageFilenameTemplateImmutable",
        "defaultImageFilenameTemplateValue",
        "lastImageSaveLocation",
        "isLastImageSaveLocationImmutable",
        "defaultLastImageSaveLocationValue",
        "lastImageSaveAsLocation",
        "isLastImageSaveAsLocationImmutable",
        "defaultLastImageSaveAsLocationValue",
        "videoSaveLocation",
        "isVideoSaveLocationImmutable",
        "defaultVideoSaveLocationValue",
        "preferredVideoFormat",
        "isPreferredVideoFormatImmutable",
        "defaultPreferredVideoFormatValue",
        "videoFilenameTemplate",
        "isVideoFilenameTemplateImmutable",
        "defaultVideoFilenameTemplateValue",
        "lastVideoSaveLocation",
        "isLastVideoSaveLocationImmutable",
        "defaultLastVideoSaveLocationValue",
        "lastVideoSaveAsLocation",
        "isLastVideoSaveAsLocationImmutable",
        "defaultLastVideoSaveAsLocationValue",
        "EnumLaunchAction",
        "TakeRectangularScreenshot",
        "TakeFullscreenScreenshot",
        "UseLastUsedCapturemode",
        "DoNotTakeScreenshot",
        "EnumPrintKeyRunningAction",
        "TakeNewScreenshot",
        "StartNewInstance",
        "FocusWindow",
        "EnumClipboardGroup",
        "PostScreenshotDoNothing",
        "PostScreenshotCopyImage",
        "PostScreenshotCopyLocation",
        "EnumShowMagnifier",
        "ShowMagnifierNever",
        "ShowMagnifierAlways",
        "ShowMagnifierShiftHeld",
        "EnumRememberSelectionRect",
        "Never",
        "Always",
        "UntilClosed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'launchActionChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'printKeyRunningActionChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoSaveImageChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeAfterOcrChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipboardGroupChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useLightMaskColorChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showMagnifierChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useReleaseToCaptureChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rememberSelectionRectChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ocrLanguagesChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionRectChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureOnClickChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'includePointerChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoIncludePointerChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'includeDecorationsChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'includeShadowChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transientOnlyChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'quitAfterSaveCopyExportChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureDelayChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureModeChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageSaveLocationChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageCompressionQualityChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferredImageFormatChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageFilenameTemplateChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastImageSaveLocationChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastImageSaveAsLocationChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoSaveLocationChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferredVideoFormatChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoFilenameTemplateChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastVideoSaveLocationChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastVideoSaveAsLocationChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'launchAction'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isLaunchActionImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLaunchActionValue'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'printKeyRunningAction'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isPrintKeyRunningActionImmutable'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPrintKeyRunningActionValue'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoSaveImage'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isAutoSaveImageImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoSaveImageValue'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'closeAfterOcr'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isCloseAfterOcrImmutable'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCloseAfterOcrValue'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clipboardGroup'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isClipboardGroupImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClipboardGroupValue'
        QtMocHelpers::PropertyData<int>(51, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useLightMaskColor'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isUseLightMaskColorImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseLightMaskColorValue'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showMagnifier'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isShowMagnifierImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowMagnifierValue'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useReleaseToCapture'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isUseReleaseToCaptureImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseReleaseToCaptureValue'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rememberSelectionRect'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isRememberSelectionRectImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRememberSelectionRectValue'
        QtMocHelpers::PropertyData<int>(63, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ocrLanguages'
        QtMocHelpers::PropertyData<QStringList>(64, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isOcrLanguagesImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOcrLanguagesValue'
        QtMocHelpers::PropertyData<QStringList>(66, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'selectionRect'
        QtMocHelpers::PropertyData<QRectF>(67, 0x80000000 | 68, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'isSelectionRectImmutable'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSelectionRectValue'
        QtMocHelpers::PropertyData<QRectF>(70, 0x80000000 | 68, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'captureOnClick'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isCaptureOnClickImmutable'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCaptureOnClickValue'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'includePointer'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isIncludePointerImmutable'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIncludePointerValue'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'videoIncludePointer'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isVideoIncludePointerImmutable'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVideoIncludePointerValue'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'includeDecorations'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isIncludeDecorationsImmutable'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIncludeDecorationsValue'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'includeShadow'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isIncludeShadowImmutable'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIncludeShadowValue'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transientOnly'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isTransientOnlyImmutable'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTransientOnlyValue'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'quitAfterSaveCopyExport'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isQuitAfterSaveCopyExportImmutable'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultQuitAfterSaveCopyExportValue'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureDelay'
        QtMocHelpers::PropertyData<double>(92, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isCaptureDelayImmutable'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCaptureDelayValue'
        QtMocHelpers::PropertyData<double>(94, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureMode'
        QtMocHelpers::PropertyData<int>(95, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isCaptureModeImmutable'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCaptureModeValue'
        QtMocHelpers::PropertyData<int>(97, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageSaveLocation'
        QtMocHelpers::PropertyData<QUrl>(98, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'isImageSaveLocationImmutable'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultImageSaveLocationValue'
        QtMocHelpers::PropertyData<QUrl>(101, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'imageCompressionQuality'
        QtMocHelpers::PropertyData<uint>(102, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isImageCompressionQualityImmutable'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultImageCompressionQualityValue'
        QtMocHelpers::PropertyData<uint>(104, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preferredImageFormat'
        QtMocHelpers::PropertyData<QString>(105, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isPreferredImageFormatImmutable'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPreferredImageFormatValue'
        QtMocHelpers::PropertyData<QString>(107, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageFilenameTemplate'
        QtMocHelpers::PropertyData<QString>(108, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isImageFilenameTemplateImmutable'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultImageFilenameTemplateValue'
        QtMocHelpers::PropertyData<QString>(110, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastImageSaveLocation'
        QtMocHelpers::PropertyData<QUrl>(111, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 24),
        // property 'isLastImageSaveLocationImmutable'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastImageSaveLocationValue'
        QtMocHelpers::PropertyData<QUrl>(113, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'lastImageSaveAsLocation'
        QtMocHelpers::PropertyData<QUrl>(114, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
        // property 'isLastImageSaveAsLocationImmutable'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastImageSaveAsLocationValue'
        QtMocHelpers::PropertyData<QUrl>(116, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'videoSaveLocation'
        QtMocHelpers::PropertyData<QUrl>(117, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 26),
        // property 'isVideoSaveLocationImmutable'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVideoSaveLocationValue'
        QtMocHelpers::PropertyData<QUrl>(119, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'preferredVideoFormat'
        QtMocHelpers::PropertyData<int>(120, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isPreferredVideoFormatImmutable'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPreferredVideoFormatValue'
        QtMocHelpers::PropertyData<int>(122, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'videoFilenameTemplate'
        QtMocHelpers::PropertyData<QString>(123, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isVideoFilenameTemplateImmutable'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVideoFilenameTemplateValue'
        QtMocHelpers::PropertyData<QString>(125, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastVideoSaveLocation'
        QtMocHelpers::PropertyData<QUrl>(126, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 29),
        // property 'isLastVideoSaveLocationImmutable'
        QtMocHelpers::PropertyData<bool>(127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastVideoSaveLocationValue'
        QtMocHelpers::PropertyData<QUrl>(128, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'lastVideoSaveAsLocation'
        QtMocHelpers::PropertyData<QUrl>(129, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 30),
        // property 'isLastVideoSaveAsLocationImmutable'
        QtMocHelpers::PropertyData<bool>(130, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastVideoSaveAsLocationValue'
        QtMocHelpers::PropertyData<QUrl>(131, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EnumLaunchAction'
        QtMocHelpers::EnumData<enum EnumLaunchAction>(132, 132, QMC::EnumFlags{}).add({
            {  133, EnumLaunchAction::TakeRectangularScreenshot },
            {  134, EnumLaunchAction::TakeFullscreenScreenshot },
            {  135, EnumLaunchAction::UseLastUsedCapturemode },
            {  136, EnumLaunchAction::DoNotTakeScreenshot },
        }),
        // enum 'EnumPrintKeyRunningAction'
        QtMocHelpers::EnumData<enum EnumPrintKeyRunningAction>(137, 137, QMC::EnumFlags{}).add({
            {  138, EnumPrintKeyRunningAction::TakeNewScreenshot },
            {  139, EnumPrintKeyRunningAction::StartNewInstance },
            {  140, EnumPrintKeyRunningAction::FocusWindow },
        }),
        // enum 'EnumClipboardGroup'
        QtMocHelpers::EnumData<enum EnumClipboardGroup>(141, 141, QMC::EnumFlags{}).add({
            {  142, EnumClipboardGroup::PostScreenshotDoNothing },
            {  143, EnumClipboardGroup::PostScreenshotCopyImage },
            {  144, EnumClipboardGroup::PostScreenshotCopyLocation },
        }),
        // enum 'EnumShowMagnifier'
        QtMocHelpers::EnumData<enum EnumShowMagnifier>(145, 145, QMC::EnumFlags{}).add({
            {  146, EnumShowMagnifier::ShowMagnifierNever },
            {  147, EnumShowMagnifier::ShowMagnifierAlways },
            {  148, EnumShowMagnifier::ShowMagnifierShiftHeld },
        }),
        // enum 'EnumRememberSelectionRect'
        QtMocHelpers::EnumData<enum EnumRememberSelectionRect>(149, 149, QMC::EnumFlags{}).add({
            {  150, EnumRememberSelectionRect::Never },
            {  151, EnumRememberSelectionRect::Always },
            {  152, EnumRememberSelectionRect::UntilClosed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Settings, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Settings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8SettingsE_t>.metaTypes,
    nullptr
} };

void Settings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Settings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->launchActionChanged(); break;
        case 1: _t->printKeyRunningActionChanged(); break;
        case 2: _t->autoSaveImageChanged(); break;
        case 3: _t->closeAfterOcrChanged(); break;
        case 4: _t->clipboardGroupChanged(); break;
        case 5: _t->useLightMaskColorChanged(); break;
        case 6: _t->showMagnifierChanged(); break;
        case 7: _t->useReleaseToCaptureChanged(); break;
        case 8: _t->rememberSelectionRectChanged(); break;
        case 9: _t->ocrLanguagesChanged(); break;
        case 10: _t->selectionRectChanged(); break;
        case 11: _t->captureOnClickChanged(); break;
        case 12: _t->includePointerChanged(); break;
        case 13: _t->videoIncludePointerChanged(); break;
        case 14: _t->includeDecorationsChanged(); break;
        case 15: _t->includeShadowChanged(); break;
        case 16: _t->transientOnlyChanged(); break;
        case 17: _t->quitAfterSaveCopyExportChanged(); break;
        case 18: _t->captureDelayChanged(); break;
        case 19: _t->captureModeChanged(); break;
        case 20: _t->imageSaveLocationChanged(); break;
        case 21: _t->imageCompressionQualityChanged(); break;
        case 22: _t->preferredImageFormatChanged(); break;
        case 23: _t->imageFilenameTemplateChanged(); break;
        case 24: _t->lastImageSaveLocationChanged(); break;
        case 25: _t->lastImageSaveAsLocationChanged(); break;
        case 26: _t->videoSaveLocationChanged(); break;
        case 27: _t->preferredVideoFormatChanged(); break;
        case 28: _t->videoFilenameTemplateChanged(); break;
        case 29: _t->lastVideoSaveLocationChanged(); break;
        case 30: _t->lastVideoSaveAsLocationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::launchActionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::printKeyRunningActionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::autoSaveImageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::closeAfterOcrChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::clipboardGroupChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::useLightMaskColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::showMagnifierChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::useReleaseToCaptureChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::rememberSelectionRectChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::ocrLanguagesChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::selectionRectChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::captureOnClickChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::includePointerChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::videoIncludePointerChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::includeDecorationsChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::includeShadowChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::transientOnlyChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::quitAfterSaveCopyExportChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::captureDelayChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::captureModeChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::imageSaveLocationChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::imageCompressionQualityChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::preferredImageFormatChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::imageFilenameTemplateChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::lastImageSaveLocationChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::lastImageSaveAsLocationChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::videoSaveLocationChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::preferredVideoFormatChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::videoFilenameTemplateChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::lastVideoSaveLocationChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::lastVideoSaveAsLocationChanged, 30))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->launchAction(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isLaunchActionImmutable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->defaultLaunchActionValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->printKeyRunningAction(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isPrintKeyRunningActionImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultPrintKeyRunningActionValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->autoSaveImage(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isAutoSaveImageImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultAutoSaveImageValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->closeAfterOcr(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isCloseAfterOcrImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultCloseAfterOcrValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->clipboardGroup(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isClipboardGroupImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultClipboardGroupValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->useLightMaskColor(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isUseLightMaskColorImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultUseLightMaskColorValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->showMagnifier(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isShowMagnifierImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultShowMagnifierValue(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->useReleaseToCapture(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isUseReleaseToCaptureImmutable(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->defaultUseReleaseToCaptureValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->rememberSelectionRect(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isRememberSelectionRectImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultRememberSelectionRectValue(); break;
        case 27: *reinterpret_cast<QStringList*>(_v) = _t->ocrLanguages(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isOcrLanguagesImmutable(); break;
        case 29: *reinterpret_cast<QStringList*>(_v) = _t->defaultOcrLanguagesValue(); break;
        case 30: *reinterpret_cast<QRectF*>(_v) = _t->selectionRect(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isSelectionRectImmutable(); break;
        case 32: *reinterpret_cast<QRectF*>(_v) = _t->defaultSelectionRectValue(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->captureOnClick(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isCaptureOnClickImmutable(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->defaultCaptureOnClickValue(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->includePointer(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isIncludePointerImmutable(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->defaultIncludePointerValue(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->videoIncludePointer(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isVideoIncludePointerImmutable(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->defaultVideoIncludePointerValue(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->includeDecorations(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isIncludeDecorationsImmutable(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->defaultIncludeDecorationsValue(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->includeShadow(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isIncludeShadowImmutable(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->defaultIncludeShadowValue(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->transientOnly(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isTransientOnlyImmutable(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->defaultTransientOnlyValue(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->quitAfterSaveCopyExport(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isQuitAfterSaveCopyExportImmutable(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->defaultQuitAfterSaveCopyExportValue(); break;
        case 54: *reinterpret_cast<double*>(_v) = _t->captureDelay(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isCaptureDelayImmutable(); break;
        case 56: *reinterpret_cast<double*>(_v) = _t->defaultCaptureDelayValue(); break;
        case 57: *reinterpret_cast<int*>(_v) = _t->captureMode(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isCaptureModeImmutable(); break;
        case 59: *reinterpret_cast<int*>(_v) = _t->defaultCaptureModeValue(); break;
        case 60: *reinterpret_cast<QUrl*>(_v) = _t->imageSaveLocation(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isImageSaveLocationImmutable(); break;
        case 62: *reinterpret_cast<QUrl*>(_v) = _t->defaultImageSaveLocationValue(); break;
        case 63: *reinterpret_cast<uint*>(_v) = _t->imageCompressionQuality(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isImageCompressionQualityImmutable(); break;
        case 65: *reinterpret_cast<uint*>(_v) = _t->defaultImageCompressionQualityValue(); break;
        case 66: *reinterpret_cast<QString*>(_v) = _t->preferredImageFormat(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isPreferredImageFormatImmutable(); break;
        case 68: *reinterpret_cast<QString*>(_v) = _t->defaultPreferredImageFormatValue(); break;
        case 69: *reinterpret_cast<QString*>(_v) = _t->imageFilenameTemplate(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isImageFilenameTemplateImmutable(); break;
        case 71: *reinterpret_cast<QString*>(_v) = _t->defaultImageFilenameTemplateValue(); break;
        case 72: *reinterpret_cast<QUrl*>(_v) = _t->lastImageSaveLocation(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isLastImageSaveLocationImmutable(); break;
        case 74: *reinterpret_cast<QUrl*>(_v) = _t->defaultLastImageSaveLocationValue(); break;
        case 75: *reinterpret_cast<QUrl*>(_v) = _t->lastImageSaveAsLocation(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isLastImageSaveAsLocationImmutable(); break;
        case 77: *reinterpret_cast<QUrl*>(_v) = _t->defaultLastImageSaveAsLocationValue(); break;
        case 78: *reinterpret_cast<QUrl*>(_v) = _t->videoSaveLocation(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isVideoSaveLocationImmutable(); break;
        case 80: *reinterpret_cast<QUrl*>(_v) = _t->defaultVideoSaveLocationValue(); break;
        case 81: *reinterpret_cast<int*>(_v) = _t->preferredVideoFormat(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isPreferredVideoFormatImmutable(); break;
        case 83: *reinterpret_cast<int*>(_v) = _t->defaultPreferredVideoFormatValue(); break;
        case 84: *reinterpret_cast<QString*>(_v) = _t->videoFilenameTemplate(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isVideoFilenameTemplateImmutable(); break;
        case 86: *reinterpret_cast<QString*>(_v) = _t->defaultVideoFilenameTemplateValue(); break;
        case 87: *reinterpret_cast<QUrl*>(_v) = _t->lastVideoSaveLocation(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isLastVideoSaveLocationImmutable(); break;
        case 89: *reinterpret_cast<QUrl*>(_v) = _t->defaultLastVideoSaveLocationValue(); break;
        case 90: *reinterpret_cast<QUrl*>(_v) = _t->lastVideoSaveAsLocation(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isLastVideoSaveAsLocationImmutable(); break;
        case 92: *reinterpret_cast<QUrl*>(_v) = _t->defaultLastVideoSaveAsLocationValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLaunchAction(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setPrintKeyRunningAction(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setAutoSaveImage(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setCloseAfterOcr(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setClipboardGroup(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setUseLightMaskColor(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setShowMagnifier(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setUseReleaseToCapture(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setRememberSelectionRect(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setOcrLanguages(*reinterpret_cast<QStringList*>(_v)); break;
        case 30: _t->setSelectionRect(*reinterpret_cast<QRectF*>(_v)); break;
        case 33: _t->setCaptureOnClick(*reinterpret_cast<bool*>(_v)); break;
        case 36: _t->setIncludePointer(*reinterpret_cast<bool*>(_v)); break;
        case 39: _t->setVideoIncludePointer(*reinterpret_cast<bool*>(_v)); break;
        case 42: _t->setIncludeDecorations(*reinterpret_cast<bool*>(_v)); break;
        case 45: _t->setIncludeShadow(*reinterpret_cast<bool*>(_v)); break;
        case 48: _t->setTransientOnly(*reinterpret_cast<bool*>(_v)); break;
        case 51: _t->setQuitAfterSaveCopyExport(*reinterpret_cast<bool*>(_v)); break;
        case 54: _t->setCaptureDelay(*reinterpret_cast<double*>(_v)); break;
        case 57: _t->setCaptureMode(*reinterpret_cast<int*>(_v)); break;
        case 60: _t->setImageSaveLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 63: _t->setImageCompressionQuality(*reinterpret_cast<uint*>(_v)); break;
        case 66: _t->setPreferredImageFormat(*reinterpret_cast<QString*>(_v)); break;
        case 69: _t->setImageFilenameTemplate(*reinterpret_cast<QString*>(_v)); break;
        case 72: _t->setLastImageSaveLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 75: _t->setLastImageSaveAsLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 78: _t->setVideoSaveLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 81: _t->setPreferredVideoFormat(*reinterpret_cast<int*>(_v)); break;
        case 84: _t->setVideoFilenameTemplate(*reinterpret_cast<QString*>(_v)); break;
        case 87: _t->setLastVideoSaveLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 90: _t->setLastVideoSaveAsLocation(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Settings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Settings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Settings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 93;
    }
    return _id;
}

// SIGNAL 0
void Settings::launchActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Settings::printKeyRunningActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Settings::autoSaveImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Settings::closeAfterOcrChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Settings::clipboardGroupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Settings::useLightMaskColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Settings::showMagnifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Settings::useReleaseToCaptureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Settings::rememberSelectionRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Settings::ocrLanguagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Settings::selectionRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Settings::captureOnClickChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Settings::includePointerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Settings::videoIncludePointerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Settings::includeDecorationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Settings::includeShadowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Settings::transientOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Settings::quitAfterSaveCopyExportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Settings::captureDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Settings::captureModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Settings::imageSaveLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Settings::imageCompressionQualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Settings::preferredImageFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Settings::imageFilenameTemplateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Settings::lastImageSaveLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Settings::lastImageSaveAsLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Settings::videoSaveLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Settings::preferredVideoFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Settings::videoFilenameTemplateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void Settings::lastVideoSaveLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void Settings::lastVideoSaveAsLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}
QT_WARNING_POP
