/****************************************************************************
** Meta object code from reading C++ file 'Geometry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../spectacle-6.6.90/src/Geometry.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Geometry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8GeometryE_t {};
} // unnamed namespace

template <> constexpr inline auto Geometry::qt_create_metaobjectdata<qt_meta_tag_ZN8GeometryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Geometry",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "dpx",
        "",
        "dpr",
        "dprRound",
        "value",
        "QPointF",
        "point",
        "dprCeil",
        "dprFloor",
        "mapFromPlatformValue",
        "mapFromPlatformPoint",
        "mapFromPlatformRect",
        "QRectF",
        "rect",
        "logicalScreensRect",
        "mapToPlatformValue",
        "mapToPlatformPoint",
        "mapToPlatformRect",
        "platformUnifiedRect",
        "rawSize",
        "QSize",
        "QSizeF",
        "size",
        "rectNormalized",
        "x",
        "y",
        "w",
        "h",
        "rectAdjusted",
        "xp1",
        "yp1",
        "xp2",
        "yp2",
        "rectAdjustedVisually",
        "rectScaled",
        "scale",
        "rectIntersected",
        "rect1",
        "rect2",
        "rectBounded",
        "boundsRect",
        "Qt::Orientations",
        "orientations",
        "width",
        "height",
        "rectClipped",
        "clipRect",
        "rectContains",
        "v",
        "ellipseContains",
        "ellipseX",
        "ellipseY",
        "ellipseWidth",
        "ellipseHeight",
        "rectIntersects",
        "isEmpty",
        "isNull"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'dpx'
        QtMocHelpers::MethodData<qreal(qreal)>(5, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 7 },
        }}),
        // Method 'dprRound'
        QtMocHelpers::MethodData<qreal(qreal, qreal)>(8, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 9 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'dprRound'
        QtMocHelpers::MethodData<QPointF(QPointF, qreal)>(8, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'dprCeil'
        QtMocHelpers::MethodData<qreal(qreal, qreal)>(12, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 9 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'dprFloor'
        QtMocHelpers::MethodData<qreal(qreal, qreal)>(13, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 9 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'mapFromPlatformValue'
        QtMocHelpers::MethodData<qreal(qreal, qreal)>(14, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 9 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'mapFromPlatformPoint'
        QtMocHelpers::MethodData<QPointF(const QPointF &, qreal)>(15, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'mapFromPlatformRect'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal)>(16, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'logicalScreensRect'
        QtMocHelpers::MethodData<QRectF()>(19, 6, QMC::AccessPublic, 0x80000000 | 17),
        // Method 'mapToPlatformValue'
        QtMocHelpers::MethodData<qreal(qreal, qreal)>(20, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 9 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'mapToPlatformPoint'
        QtMocHelpers::MethodData<QPointF(const QPointF &, qreal)>(21, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'mapToPlatformRect'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal)>(22, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'platformUnifiedRect'
        QtMocHelpers::MethodData<QRectF()>(23, 6, QMC::AccessPublic, 0x80000000 | 17),
        // Method 'rawSize'
        QtMocHelpers::MethodData<QSize(const QSizeF &, qreal)>(24, 6, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 26, 27 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'rectNormalized'
        QtMocHelpers::MethodData<QRectF(const QRectF &)>(28, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'rectNormalized'
        QtMocHelpers::MethodData<QRectF(qreal, qreal, qreal, qreal)>(28, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 }, { QMetaType::QReal, 31 }, { QMetaType::QReal, 32 },
        }}),
        // Method 'rectAdjusted'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal, qreal, qreal, qreal)>(33, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 34 }, { QMetaType::QReal, 35 }, { QMetaType::QReal, 36 },
            { QMetaType::QReal, 37 },
        }}),
        // Method 'rectAdjustedVisually'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal, qreal, qreal, qreal)>(38, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 34 }, { QMetaType::QReal, 35 }, { QMetaType::QReal, 36 },
            { QMetaType::QReal, 37 },
        }}),
        // Method 'rectScaled'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal)>(39, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 40 },
        }}),
        // Method 'rectIntersected'
        QtMocHelpers::MethodData<QRectF(const QRectF &, const QRectF &)>(41, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 42 }, { 0x80000000 | 17, 43 },
        }}),
        // Method 'rectBounded'
        QtMocHelpers::MethodData<QRectF(const QRectF &, const QRectF &, Qt::Orientations)>(44, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 45 }, { 0x80000000 | 46, 47 },
        }}),
        // Method 'rectBounded'
        QtMocHelpers::MethodData<QRectF(const QRectF &, const QRectF &)>(44, 6, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 45 },
        }}),
        // Method 'rectBounded'
        QtMocHelpers::MethodData<QRectF(qreal, qreal, qreal, qreal, const QRectF &, Qt::Orientations)>(44, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 }, { QMetaType::QReal, 48 }, { QMetaType::QReal, 49 },
            { 0x80000000 | 17, 45 }, { 0x80000000 | 46, 47 },
        }}),
        // Method 'rectBounded'
        QtMocHelpers::MethodData<QRectF(qreal, qreal, qreal, qreal, const QRectF &)>(44, 6, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 17, {{
            { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 }, { QMetaType::QReal, 48 }, { QMetaType::QReal, 49 },
            { 0x80000000 | 17, 45 },
        }}),
        // Method 'rectClipped'
        QtMocHelpers::MethodData<QRectF(const QRectF &, const QRectF &, Qt::Orientations)>(50, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 51 }, { 0x80000000 | 46, 47 },
        }}),
        // Method 'rectClipped'
        QtMocHelpers::MethodData<QRectF(const QRectF &, const QRectF &)>(50, 6, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 51 },
        }}),
        // Method 'rectContains'
        QtMocHelpers::MethodData<bool(const QRectF &, qreal, Qt::Orientations)>(52, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 53 }, { 0x80000000 | 46, 47 },
        }}),
        // Method 'rectContains'
        QtMocHelpers::MethodData<bool(const QRectF &, qreal)>(52, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 53 },
        }}),
        // Method 'rectContains'
        QtMocHelpers::MethodData<bool(const QRectF &, qreal, qreal)>(52, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 },
        }}),
        // Method 'rectContains'
        QtMocHelpers::MethodData<bool(const QRectF &, const QPointF &)>(52, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'rectContains'
        QtMocHelpers::MethodData<bool(const QRectF &, const QRectF &)>(52, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 42 }, { 0x80000000 | 17, 43 },
        }}),
        // Method 'rectContains'
        QtMocHelpers::MethodData<bool(const QRectF &, qreal, qreal, qreal, qreal)>(52, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 }, { QMetaType::QReal, 31 },
            { QMetaType::QReal, 32 },
        }}),
        // Method 'ellipseContains'
        QtMocHelpers::MethodData<bool(qreal, qreal, qreal, qreal, qreal, qreal)>(54, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QReal, 55 }, { QMetaType::QReal, 56 }, { QMetaType::QReal, 57 }, { QMetaType::QReal, 58 },
            { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 },
        }}),
        // Method 'ellipseContains'
        QtMocHelpers::MethodData<bool(const QRectF &, qreal, qreal)>(54, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 },
        }}),
        // Method 'ellipseContains'
        QtMocHelpers::MethodData<bool(const QRectF &, const QPointF &)>(54, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'rectIntersects'
        QtMocHelpers::MethodData<bool(const QRectF &, const QRectF &)>(59, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 42 }, { 0x80000000 | 17, 43 },
        }}),
        // Method 'rectIntersects'
        QtMocHelpers::MethodData<bool(const QRectF &, qreal, qreal, qreal, qreal)>(59, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 }, { QMetaType::QReal, 31 },
            { QMetaType::QReal, 32 },
        }}),
        // Method 'isEmpty'
        QtMocHelpers::MethodData<bool(qreal, qreal)>(60, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QReal, 31 }, { QMetaType::QReal, 32 },
        }}),
        // Method 'isEmpty'
        QtMocHelpers::MethodData<bool(const QSizeF &)>(60, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Method 'isEmpty'
        QtMocHelpers::MethodData<bool(const QRectF &)>(60, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'isNull'
        QtMocHelpers::MethodData<bool(qreal, qreal)>(61, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QReal, 31 }, { QMetaType::QReal, 32 },
        }}),
        // Method 'isNull'
        QtMocHelpers::MethodData<bool(const QSizeF &)>(61, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Method 'isNull'
        QtMocHelpers::MethodData<bool(const QRectF &)>(61, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Geometry, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Geometry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8GeometryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8GeometryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8GeometryE_t>.metaTypes,
    nullptr
} };

void Geometry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Geometry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { qreal _r = _t->dpx((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 1: { qreal _r = _t->dprRound((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 2: { QPointF _r = _t->dprRound((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 3: { qreal _r = _t->dprCeil((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 4: { qreal _r = _t->dprFloor((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 5: { qreal _r = _t->mapFromPlatformValue((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 6: { QPointF _r = _t->mapFromPlatformPoint((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 7: { QRectF _r = _t->mapFromPlatformRect((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 8: { QRectF _r = _t->logicalScreensRect();
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 9: { qreal _r = _t->mapToPlatformValue((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 10: { QPointF _r = _t->mapToPlatformPoint((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 11: { QRectF _r = _t->mapToPlatformRect((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 12: { QRectF _r = _t->platformUnifiedRect();
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 13: { QSize _r = _t->rawSize((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        case 14: { QRectF _r = _t->rectNormalized((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 15: { QRectF _r = _t->rectNormalized((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 16: { QRectF _r = _t->rectAdjusted((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 17: { QRectF _r = _t->rectAdjustedVisually((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 18: { QRectF _r = _t->rectScaled((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 19: { QRectF _r = _t->rectIntersected((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 20: { QRectF _r = _t->rectBounded((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientations>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 21: { QRectF _r = _t->rectBounded((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 22: { QRectF _r = _t->rectBounded((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientations>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 23: { QRectF _r = _t->rectBounded((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 24: { QRectF _r = _t->rectClipped((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientations>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 25: { QRectF _r = _t->rectClipped((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->rectContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientations>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->rectContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->rectContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->rectContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->rectContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->rectContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->ellipseContains((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->ellipseContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->ellipseContains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->rectIntersects((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->rectIntersects((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->isEmpty((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->isEmpty((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->isEmpty((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->isNull((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->isNull((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->isNull((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Geometry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Geometry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8GeometryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Geometry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 43;
    }
    return _id;
}
QT_WARNING_POP
