/********************************************************************************
** Form generated from reading UI file 'GeneralOptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALOPTIONS_H
#define UI_GENERALOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralOptions
{
public:
    QFormLayout *formLayout;
    QLabel *launchActionSpectacleLabel;
    QComboBox *kcfg_launchAction;
    QSpacerItem *verticalSpacer;
    QLabel *afterScreenshotLabel;
    QCheckBox *kcfg_autoSaveImage;
    QComboBox *kcfg_clipboardGroup;
    QSpacerItem *verticalSpacer_1;
    KTitleWidget *runningTitle;
    QLabel *printKeyActionLabel;
    QComboBox *kcfg_printKeyRunningAction;
    QSpacerItem *verticalSpacer_2;
    KTitleWidget *regionTitle;
    QLabel *generalLabel;
    QCheckBox *kcfg_useLightMaskColor;
    QCheckBox *kcfg_useReleaseToCapture;
    QLabel *label;
    QComboBox *kcfg_showMagnifier;
    QLabel *rememberLabel;
    QComboBox *kcfg_rememberSelectionRect;
    QSpacerItem *verticalSpacer_3;
    KTitleWidget *ocrTitle;
    QLabel *ocrLanguageLabel;
    QScrollArea *ocrLanguageScrollArea;
    QWidget *ocrLanguageContainer;
    QVBoxLayout *ocrLanguageLayout;
    QLabel *closeAfterOcrLabel;
    QHBoxLayout *closeAfterOcrLayout;
    QCheckBox *kcfg_closeAfterOcr;
    QLabel *closeAfterOcrInfo;
    QSpacerItem *horizontalSpacer_close_ocr;
    QWidget *ocrUnavailableWidget;
    QHBoxLayout *ocrUnavailableLayout;
    QLabel *ocrUnavailableLabel;
    QLabel *ocrInfoIcon;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *GeneralOptions)
    {
        if (GeneralOptions->objectName().isEmpty())
            GeneralOptions->setObjectName("GeneralOptions");
        GeneralOptions->resize(463, 542);
        formLayout = new QFormLayout(GeneralOptions);
        formLayout->setObjectName("formLayout");
        launchActionSpectacleLabel = new QLabel(GeneralOptions);
        launchActionSpectacleLabel->setObjectName("launchActionSpectacleLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, launchActionSpectacleLabel);

        kcfg_launchAction = new QComboBox(GeneralOptions);
        kcfg_launchAction->addItem(QString());
        kcfg_launchAction->addItem(QString());
        kcfg_launchAction->addItem(QString());
        kcfg_launchAction->addItem(QString());
        kcfg_launchAction->setObjectName("kcfg_launchAction");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_launchAction);

        verticalSpacer = new QSpacerItem(0, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(1, QFormLayout::ItemRole::SpanningRole, verticalSpacer);

        afterScreenshotLabel = new QLabel(GeneralOptions);
        afterScreenshotLabel->setObjectName("afterScreenshotLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, afterScreenshotLabel);

        kcfg_autoSaveImage = new QCheckBox(GeneralOptions);
        kcfg_autoSaveImage->setObjectName("kcfg_autoSaveImage");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_autoSaveImage);

        kcfg_clipboardGroup = new QComboBox(GeneralOptions);
        kcfg_clipboardGroup->addItem(QString());
        kcfg_clipboardGroup->addItem(QString());
        kcfg_clipboardGroup->addItem(QString());
        kcfg_clipboardGroup->setObjectName("kcfg_clipboardGroup");
        kcfg_clipboardGroup->setContentsMargins(0, -1, -1, -1);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_clipboardGroup);

        verticalSpacer_1 = new QSpacerItem(0, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(4, QFormLayout::ItemRole::SpanningRole, verticalSpacer_1);

        runningTitle = new KTitleWidget(GeneralOptions);
        runningTitle->setObjectName("runningTitle");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, runningTitle);

        printKeyActionLabel = new QLabel(GeneralOptions);
        printKeyActionLabel->setObjectName("printKeyActionLabel");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, printKeyActionLabel);

        kcfg_printKeyRunningAction = new QComboBox(GeneralOptions);
        kcfg_printKeyRunningAction->addItem(QString());
        kcfg_printKeyRunningAction->addItem(QString());
        kcfg_printKeyRunningAction->addItem(QString());
        kcfg_printKeyRunningAction->setObjectName("kcfg_printKeyRunningAction");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_printKeyRunningAction);

        verticalSpacer_2 = new QSpacerItem(0, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(7, QFormLayout::ItemRole::SpanningRole, verticalSpacer_2);

        regionTitle = new KTitleWidget(GeneralOptions);
        regionTitle->setObjectName("regionTitle");

        formLayout->setWidget(8, QFormLayout::ItemRole::SpanningRole, regionTitle);

        generalLabel = new QLabel(GeneralOptions);
        generalLabel->setObjectName("generalLabel");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, generalLabel);

        kcfg_useLightMaskColor = new QCheckBox(GeneralOptions);
        kcfg_useLightMaskColor->setObjectName("kcfg_useLightMaskColor");

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, kcfg_useLightMaskColor);

        kcfg_useReleaseToCapture = new QCheckBox(GeneralOptions);
        kcfg_useReleaseToCapture->setObjectName("kcfg_useReleaseToCapture");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, kcfg_useReleaseToCapture);

        label = new QLabel(GeneralOptions);
        label->setObjectName("label");

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, label);

        kcfg_showMagnifier = new QComboBox(GeneralOptions);
        kcfg_showMagnifier->addItem(QString());
        kcfg_showMagnifier->addItem(QString());
        kcfg_showMagnifier->addItem(QString());
        kcfg_showMagnifier->setObjectName("kcfg_showMagnifier");

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, kcfg_showMagnifier);

        rememberLabel = new QLabel(GeneralOptions);
        rememberLabel->setObjectName("rememberLabel");

        formLayout->setWidget(12, QFormLayout::ItemRole::LabelRole, rememberLabel);

        kcfg_rememberSelectionRect = new QComboBox(GeneralOptions);
        kcfg_rememberSelectionRect->addItem(QString());
        kcfg_rememberSelectionRect->addItem(QString());
        kcfg_rememberSelectionRect->addItem(QString());
        kcfg_rememberSelectionRect->setObjectName("kcfg_rememberSelectionRect");

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, kcfg_rememberSelectionRect);

        verticalSpacer_3 = new QSpacerItem(10, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(14, QFormLayout::ItemRole::SpanningRole, verticalSpacer_3);

        ocrTitle = new KTitleWidget(GeneralOptions);
        ocrTitle->setObjectName("ocrTitle");

        formLayout->setWidget(15, QFormLayout::ItemRole::SpanningRole, ocrTitle);

        ocrLanguageLabel = new QLabel(GeneralOptions);
        ocrLanguageLabel->setObjectName("ocrLanguageLabel");

        formLayout->setWidget(16, QFormLayout::ItemRole::LabelRole, ocrLanguageLabel);

        ocrLanguageScrollArea = new QScrollArea(GeneralOptions);
        ocrLanguageScrollArea->setObjectName("ocrLanguageScrollArea");
        ocrLanguageScrollArea->setWidgetResizable(true);
        ocrLanguageScrollArea->setFrameShape(QFrame::StyledPanel);
        ocrLanguageScrollArea->setMaximumHeight(120);
        ocrLanguageScrollArea->setMinimumHeight(60);
        ocrLanguageScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        ocrLanguageContainer = new QWidget();
        ocrLanguageContainer->setObjectName("ocrLanguageContainer");
        ocrLanguageContainer->setGeometry(QRect(0, 0, 69, 69));
        ocrLanguageLayout = new QVBoxLayout(ocrLanguageContainer);
        ocrLanguageLayout->setObjectName("ocrLanguageLayout");
        ocrLanguageScrollArea->setWidget(ocrLanguageContainer);

        formLayout->setWidget(16, QFormLayout::ItemRole::FieldRole, ocrLanguageScrollArea);

        closeAfterOcrLabel = new QLabel(GeneralOptions);
        closeAfterOcrLabel->setObjectName("closeAfterOcrLabel");

        formLayout->setWidget(17, QFormLayout::ItemRole::LabelRole, closeAfterOcrLabel);

        closeAfterOcrLayout = new QHBoxLayout();
        closeAfterOcrLayout->setObjectName("closeAfterOcrLayout");
        closeAfterOcrLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_closeAfterOcr = new QCheckBox(GeneralOptions);
        kcfg_closeAfterOcr->setObjectName("kcfg_closeAfterOcr");

        closeAfterOcrLayout->addWidget(kcfg_closeAfterOcr);

        closeAfterOcrInfo = new QLabel(GeneralOptions);
        closeAfterOcrInfo->setObjectName("closeAfterOcrInfo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(closeAfterOcrInfo->sizePolicy().hasHeightForWidth());
        closeAfterOcrInfo->setSizePolicy(sizePolicy);
        closeAfterOcrInfo->setMinimumSize(QSize(16, 16));
        closeAfterOcrInfo->setMaximumSize(QSize(16, 16));
        closeAfterOcrInfo->setScaledContents(true);

        closeAfterOcrLayout->addWidget(closeAfterOcrInfo);

        horizontalSpacer_close_ocr = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        closeAfterOcrLayout->addItem(horizontalSpacer_close_ocr);


        formLayout->setLayout(17, QFormLayout::ItemRole::FieldRole, closeAfterOcrLayout);

        ocrUnavailableWidget = new QWidget(GeneralOptions);
        ocrUnavailableWidget->setObjectName("ocrUnavailableWidget");
        ocrUnavailableWidget->setVisible(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ocrUnavailableWidget->sizePolicy().hasHeightForWidth());
        ocrUnavailableWidget->setSizePolicy(sizePolicy1);
        ocrUnavailableLayout = new QHBoxLayout(ocrUnavailableWidget);
#ifndef UI_Q_OS_MAC
        ocrUnavailableLayout->setSpacing(6);
#endif
        ocrUnavailableLayout->setContentsMargins(0, 0, 0, 0);
        ocrUnavailableLayout->setObjectName("ocrUnavailableLayout");
        ocrUnavailableLayout->setContentsMargins(0, 0, 0, 0);
        ocrUnavailableLabel = new QLabel(ocrUnavailableWidget);
        ocrUnavailableLabel->setObjectName("ocrUnavailableLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(ocrUnavailableLabel->sizePolicy().hasHeightForWidth());
        ocrUnavailableLabel->setSizePolicy(sizePolicy2);
        ocrUnavailableLabel->setWordWrap(false);

        ocrUnavailableLayout->addWidget(ocrUnavailableLabel);

        ocrInfoIcon = new QLabel(ocrUnavailableWidget);
        ocrInfoIcon->setObjectName("ocrInfoIcon");
        sizePolicy.setHeightForWidth(ocrInfoIcon->sizePolicy().hasHeightForWidth());
        ocrInfoIcon->setSizePolicy(sizePolicy);
        ocrInfoIcon->setAlignment(Qt::AlignCenter);
        ocrInfoIcon->setMinimumSize(QSize(16, 16));
        ocrInfoIcon->setMaximumSize(QSize(16, 16));
        ocrInfoIcon->setScaledContents(true);

        ocrUnavailableLayout->addWidget(ocrInfoIcon);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        ocrUnavailableLayout->addItem(horizontalSpacer);


        formLayout->setWidget(18, QFormLayout::ItemRole::SpanningRole, ocrUnavailableWidget);

        QWidget::setTabOrder(kcfg_launchAction, kcfg_autoSaveImage);
        QWidget::setTabOrder(kcfg_autoSaveImage, kcfg_clipboardGroup);
        QWidget::setTabOrder(kcfg_clipboardGroup, kcfg_printKeyRunningAction);
        QWidget::setTabOrder(kcfg_printKeyRunningAction, kcfg_useLightMaskColor);
        QWidget::setTabOrder(kcfg_useLightMaskColor, kcfg_useReleaseToCapture);
        QWidget::setTabOrder(kcfg_useReleaseToCapture, kcfg_rememberSelectionRect);
        QWidget::setTabOrder(kcfg_rememberSelectionRect, ocrLanguageScrollArea);

        retranslateUi(GeneralOptions);

        QMetaObject::connectSlotsByName(GeneralOptions);
    } // setupUi

    void retranslateUi(QWidget *GeneralOptions)
    {
        launchActionSpectacleLabel->setText(tr2i18n("When launching Spectacle:", nullptr));
        kcfg_launchAction->setItemText(0, tr2i18n("Take rectangular screenshot", nullptr));
        kcfg_launchAction->setItemText(1, tr2i18n("Take full screen screenshot", nullptr));
        kcfg_launchAction->setItemText(2, tr2i18n("Use last-used capture mode", nullptr));
        kcfg_launchAction->setItemText(3, tr2i18n("Do not take a screenshot automatically", nullptr));

        afterScreenshotLabel->setText(tr2i18n("After taking a screenshot:", nullptr));
        kcfg_autoSaveImage->setText(tr2i18n("Save file to default folder", nullptr));
        kcfg_clipboardGroup->setItemText(0, tr2i18n("Do not copy anything", nullptr));
        kcfg_clipboardGroup->setItemText(1, tr2i18n("Copy image to clipboard", nullptr));
        kcfg_clipboardGroup->setItemText(2, tr2i18n("Copy file location to clipboard", nullptr));

        runningTitle->setText(tr2i18n("While Spectacle is running", nullptr));
        printKeyActionLabel->setText(tr2i18n("Press screenshot key to:", nullptr));
        kcfg_printKeyRunningAction->setItemText(0, tr2i18n("Take a new Screenshot", nullptr));
        kcfg_printKeyRunningAction->setItemText(1, tr2i18n("Open a new Spectacle window", nullptr));
        kcfg_printKeyRunningAction->setItemText(2, tr2i18n("Return focus to Spectacle", nullptr));

        regionTitle->setText(tr2i18n("Rectangular Region Selection", nullptr));
        generalLabel->setText(tr2i18n("General:", nullptr));
        kcfg_useLightMaskColor->setText(tr2i18n("Use light background", nullptr));
        kcfg_useReleaseToCapture->setText(tr2i18n("Accept on click-and-release", nullptr));
        label->setText(tr2i18n("Show magnifier:", nullptr));
        kcfg_showMagnifier->setItemText(0, tr2i18n("Never", nullptr));
        kcfg_showMagnifier->setItemText(1, tr2i18n("Always", nullptr));
        kcfg_showMagnifier->setItemText(2, tr2i18n("While holding Shift", nullptr));

        rememberLabel->setText(tr2i18n("Remember selected area:", nullptr));
        kcfg_rememberSelectionRect->setItemText(0, tr2i18n("Never", nullptr));
        kcfg_rememberSelectionRect->setItemText(1, tr2i18n("Always", nullptr));
        kcfg_rememberSelectionRect->setItemText(2, tr2i18n("Until Spectacle is closed", nullptr));

        ocrTitle->setText(tr2i18n("Text Recognition (OCR)", nullptr));
        ocrLanguageLabel->setText(tr2i18n("Languages for OCR:", nullptr));
        closeAfterOcrLabel->setText(tr2i18n("Text extraction:", nullptr));
        kcfg_closeAfterOcr->setText(tr2i18n("Close after extraction (skips auto-save)", nullptr));
#if QT_CONFIG(tooltip)
        closeAfterOcrInfo->setToolTip(tr2i18n("Spectacle will close after text extraction and automatic saving will be skipped.", nullptr));
#endif // QT_CONFIG(tooltip)
        ocrUnavailableLabel->setText(tr2i18n("OCR functionality is not available", nullptr));
#if QT_CONFIG(tooltip)
        ocrInfoIcon->setToolTip(tr2i18n("Please install the required packages:\n"
"\342\200\242 tesseract\n"
"\342\200\242 tesseract language data (e.g., tesseract-ocr-eng for English)", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)GeneralOptions;
    } // retranslateUi

};

namespace Ui {
    class GeneralOptions: public Ui_GeneralOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALOPTIONS_H

